//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:51 $
//
//==============================================================================
//
// Class: MessageSet
// 
// Overview
// --------
// An implementation of MessageFactory that loads messages from a
// file.
//
//==============================================================================

#ifndef MessageSet_h
#define MessageSet_h

#include "defs.h"
#include "ot/base/String.h"

#include <map>

OT_AUXIL_NAMESPACE_BEGIN

class OT_AUXIL_PKG MessageSet : public virtual ManagedObject
{
public:
	MessageSet(const String& org, const String& app);
	
	void addMessage(size_t messageID, const String& message);
	
	bool getMessageText(size_t messageID, String& ret) const;
	
	const String& getOrganizationName() const;
	const String& getApplicationName() const;

private:
	String m_org;
	String m_app;
	typedef std::map<size_t, String, std::less<size_t> > MessageMap;
	MessageMap m_messageMap;
};

OT_AUXIL_NAMESPACE_END

#endif //MessageSet_h

