//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:35 $
//
//==============================================================================
//
// Class: Character
// 
//==============================================================================

#ifndef OT_BASE_Character_h
#define OT_BASE_Character_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "String.h"

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG Character
{
public:

	Character();
	Character(const Character& rhs);
	Character(const CharType* pSeqStart, size_t len);
	//explicit Character(const String& str);
	explicit Character(UCS4Char ch);

	Character& operator=(const Character& rhs);

	bool operator==(const Character& rhs) const;
	bool operator!=(const Character& rhs) const;

	bool operator==(CharType c) const;
	bool operator!=(CharType c) const;

	const CharType* data() const;
	const size_t length() const;
	const CharType first() const;
	UCS4Char toUnicode() const;
	String toString() const;
	void appendToString(String&) const;

	bool isAscii() const;
	bool isDigit() const;
	bool isEOF() const;
	bool isHexDigit() const;
	bool isSpace() const;

#if defined(OT_UTF8)
	enum {MaxSeqLen=4};
#elif defined(OT_UTF16)
	enum {MaxSeqLen=2};
#elif defined(OT_UCS4) || defined(OT_UCS2)
	enum {MaxSeqLen=1};
#else
	#error Internal character encoding not correctly specified
#endif

	static Character EndOfFileCharacter;

private:
	void copyData(const CharType* pData);

private:
	CharType m_data[MaxSeqLen];
	int m_length;	
};

OT_BASE_NAMESPACE_END

// Include inline functions
#if OT_BASE_INCLUDE_INLINES
	#include "Character.inl"
#endif

#endif //OT_BASE_Character_h
