//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2002/12/31 13:29:40 $
//
//==============================================================================
//
// Class: CodeConverterBase
// 
// Overview
// --------
// Base class that contains enums, values and static methods used by
// all types of CodeConverters.
//
//==============================================================================

#ifndef OT_BASE_CodeConverterBase_h
#define OT_BASE_CodeConverterBase_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "String.h"

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG CodeConverterBase
{
public:
	enum Result {ok,              /*!< success, input buffer completely processed */
	             inputExhausted,  /*!< success, incomplete input sequence detected */
	             outputExhausted, /*!< success, output buffer full */
	             error,           /*!< conversion error */ 
	             noconv           /*!< no conversion required */ };

	static Result UTF8Encode(UCS4Char ch, Byte* to, const Byte* to_limit, Byte*& to_next);
	static Result UTF8Decode(UCS4Char& ch, const Byte *from, const Byte *from_end, const Byte *& from_next);
	static bool IsLegalUTF8(const Byte* pStart, size_t length);
	static bool IsLegalUTF16(const wchar_t* pStart, size_t length);

protected:
	static const char s_TrailingBytesForUTF8[256];
};

OT_BASE_NAMESPACE_END

#endif //OT_BASE_System_h
