//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:36 $
//
//==============================================================================
//
// Class: ConditionVariable
// 
//==============================================================================

#ifndef OT_BASE_ConditionVariable_h
#define OT_BASE_ConditionVariable_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#ifdef OT_MT

#include "FastMutex.h"
#include <list>

OT_BASE_NAMESPACE_BEGIN

class RecursiveMutex;

class OT_BASE_PKG ConditionVariable
{
public:

	ConditionVariable();
	~ConditionVariable();

	void wait(RecursiveMutex& mutex);
	bool wait(RecursiveMutex& mutex, unsigned long milliseconds);

	void signal();
	void broadcast();

private: // not implemented
	ConditionVariable(const ConditionVariable& rhs);            // cannot be copied
	ConditionVariable& operator=(const ConditionVariable& rhs); // nor assigned

private:

#if defined(OT_WIN32_THREADS)

	bool waitImplWin32(RecursiveMutex& mutex, DWORD timeout);
	void signalImplWin32(HANDLE hWaiter);

	HANDLE m_hBroadcastEvent;
	typedef std::list<HANDLE> WaitersQueue;
	WaitersQueue m_waitersQueue;
	FastMutex m_waitersLock;

#elif defined(OT_POSIX_THREADS)

	pthread_cond_t m_cv;

#else
	#error Unsupported configuration
#endif

};

OT_BASE_NAMESPACE_END

#endif //OT_MT
#endif //OT_BASE_ConditionVariable_h

