//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:37 $
//
//==============================================================================
// Class: IllegalCharacterException
// 
/**
	@class ot::IllegalCharacterException
	
	@brief Thrown when an illegal character value is detected.
	
	This can occur when @OpenTop is using the UTF-8 or UTF-16 internal encoding
	and the application creates a multi-character sequence that would generate
	an invalid Unicode character.
	
    This exception can also be thrown when attempting to construct a Character
	with an illegal Unicode code-point value.
*/
//==============================================================================

#ifndef OT_BASE_IllegalCharacterException_h
#define OT_BASE_IllegalCharacterException_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "RuntimeException.h"

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG IllegalCharacterException : public RuntimeException
{
public:
	/** Constructs an IllegalCharacterException without a detail message */
	IllegalCharacterException()
	{}

	/** Constructs an IllegalCharacterException with a detail message
	* @param message the detail message.
	*/
	IllegalCharacterException(const String& message) : 
		RuntimeException(message)
	{}
	
	virtual String getExceptionType() const {return OT_T("IllegalCharacterException");}
};

OT_BASE_NAMESPACE_END

#endif //OT_BASE_IllegalCharacterException_h

