//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:38 $
//
//==============================================================================
//
// Inline members for Character
//
//=============================================================================

#include "ManagedObject.h"
#include "debug.h"

OT_BASE_NAMESPACE_BEGIN

//==============================================================================
// ManagedObject::addRef
//
/**
   Increments the reference-count of the object.

   In multi-threaded versions of the library, the reference-count is
   incremented using an atomic, thread-safe operation.

   In the debug build, an assertion is made that the reference-count is 
   not equal to zero after it has been incremented.  This check can help
   to trap errors where an object has been erroneously deleted.

   @sa release()
*/
//==============================================================================
inline
void ManagedObject::addRef()
{
	++m_refCount;
	OT_DBG_ASSERT(m_refCount != 0);
}

//==============================================================================
// ManagedObject::release
//
/**
   Decrements the reference-count of the object.

   When the reference-count becomes zero, the virtual function onFinalRelease()
   is called which will normally delete the object.

   In multi-threaded versions of the library, the reference-count is
   decremented using an atomic, thread-safe operation.
   @sa addRef()
*/
//==============================================================================
inline
void ManagedObject::release()
{
	OT_DBG_ASSERT(m_refCount != 0);

	if(--m_refCount == 0)
		onFinalRelease();
}

OT_BASE_NAMESPACE_END
