//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:39 $
//
//==============================================================================
//
// Class: ObjectManager
// 
// Overview
// --------
// The ObjectManager class is used as a surrogate parent for objects that
// have a lifetime that is not contained by the lifetime of the creating object.
//
// This is typically the case when global objects are lazily created on first use
// but then live on until the application terminates.  It is sometimes
// necessary to keep track of and delete these objects so that memory leak
// detection software does not report false errors.
//
// The System is thus able to aid in the tracking-down of memory
// leaks by ensuring that the library is well behaved.
//
// An instance of the ObjectManager is available from the System 
// object via System::GetObjectManager().
//
//==============================================================================

#ifndef OT_BASE_ObjectManager_h
#define OT_BASE_ObjectManager_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include <list>
#include "RefPtr.h"
#include "FastMutex.h"

OT_BASE_NAMESPACE_BEGIN

class ManagedObject;

class OT_BASE_PKG ObjectManager
{
	friend class System;

public:
	
	void registerObject(ManagedObject* pObject);
	void unregisterObject(ManagedObject* pObject);

private:
	void unregisterAllObjects();

private:
	typedef std::list<RefPtr<ManagedObject> > ObjectList;
	ObjectList m_list;

#ifdef OT_MT
	FastMutex m_mutex;
#endif //OT_MT
};

OT_BASE_NAMESPACE_END

#endif //OT_BASE_ObjectManager_h

