//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:40 $
//
//==============================================================================
//
// Class: RecursiveMutex
// 
//==============================================================================

#ifndef OT_BASE_RecursiveMutex_h
#define OT_BASE_RecursiveMutex_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "Mutex.h"
#include "FastMutex.h"
#include "ThreadId.h"

#ifdef OT_MT

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG RecursiveMutex
{
	friend class ConditionVariable;

public:
	typedef AutoLock<RecursiveMutex> Lock;

	RecursiveMutex();

	void lock();
	bool tryLock();
	void unlock();
	bool isLocked();

private: // not implemented
	RecursiveMutex(const RecursiveMutex& rhs);            // cannot be copied
	RecursiveMutex& operator=(const RecursiveMutex& rhs); // nor assigned

private: // functions for use by ConditionVariable
	int getRecursionCount() const;
	void postWait(int recursionCount);
	void preWait();

private:
	Mutex m_mutex;
	//FastMutex m_internalMutex;
	ThreadId m_owningThreadId;
	int m_recursionCount;
};

OT_BASE_NAMESPACE_END

#endif //OT_MT
#endif //OT_BASE_RecursiveMutex_h
