//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/10 21:49:03 $
//
//==============================================================================
//
// Class: RefPtr<T>
// 
//==============================================================================

#ifndef OT_BASE_RefPtr_h
#define OT_BASE_RefPtr_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

OT_BASE_NAMESPACE_BEGIN

template<typename T>
class RefPtr
{
public:
	~RefPtr();
	RefPtr();

	RefPtr(const RefPtr<T>& rhs);
	RefPtr(T* ptr);

	RefPtr<T>& operator=(const RefPtr<T>& rhs);
	RefPtr<T>& operator=(T* ptr);

	bool operator<(const RefPtr<T>& rhs) const;
	bool operator==(const RefPtr<T>& rhs) const;
	bool operator==(const T* rhs) const;
	bool operator!=(const RefPtr<T>& rhs) const;
	bool operator!=(const T* rhs) const;

	bool isNull() const;

	//operator T*() const; // not defined to prevent silent conversion
	operator bool() const;
	T* operator->() const;
	T& operator*() const;
	T* get() const;

	void release();

private:
	T* m_ptr;
};

OT_BASE_NAMESPACE_END

#include "RefPtr.inl"	

#endif //OT_BASE_RefPtr_h

