//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:41 $
//
//==============================================================================

#ifndef OT_BASE_String_h
#define OT_BASE_String_h

#include "defs.h"

#include <string>

#ifndef OT_DOCUMENTATION_ONLY

// The OT_STRING_TYPE Macro is used to
// set the type of the String type used
// throughout OpenTop.  It can either be set
// explicitly, or allowed to default to the
// C++ standard string types.

#ifndef OT_STRING_TYPE
	#ifdef OT_WCHAR
		#ifdef OT_NO_WSTRING_TYPEDEF
			#define OT_STRING_TYPE std::basic_string<wchar_t>
		#else
			#define OT_STRING_TYPE std::wstring
		#endif
	#else // !OT_WCHAR
		#define OT_STRING_TYPE std::string
	#endif // OT_WCHAR
#endif // OT_STRING_TYPE

#ifndef OT_BYTE_STRING_TYPE
	#define OT_BYTE_STRING_TYPE std::string
#endif // OT_BYTE_STRING_TYPE


#endif //OT_DOCUMENTATION_ONLY

//
// namespace celbase follows:
//
OT_BASE_NAMESPACE_BEGIN

//==============================================================================
//  typedef: String
/**
	This typedef determines the String type used by @OpenTop.

    The type is set equal to the value of the pre-processor symbol @c OT_STRING_TYPE
	which is normally set to std::string (or std::wstring if the @c OT_WCHAR
	pre-processor symbol is defined).

    The library requires that the String type supports a set of operations equivalent
	to those provided by the standard C++ string @c std::basic_string<T>.
*/
//==============================================================================
typedef OT_STRING_TYPE String;

//==============================================================================
//  typedef: ByteString
/**
	This typedef determines the ByteString type used by @OpenTop.

    The type is set equal to the value of the pre-processor symbol 
	@c OT_BYTE_STRING_TYPE	which is normally set to std::string.

    The library requires that the ByteString type supports a set of operations equivalent
	to those provided by the standard C++ string @c std::basic_string<char>.
*/
//==============================================================================
typedef OT_BYTE_STRING_TYPE ByteString;

OT_BASE_NAMESPACE_END

#endif //OT_BASE_String_h
