//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/05 21:10:05 $
//
//==============================================================================
//
// Class StringIterator
//
//==============================================================================

#ifndef OT_BASE_StringIterator_h
#define OT_BASE_StringIterator_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "Character.h"
#include "SystemCodeConverter.h"

#include <utility>

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG StringIterator 

#ifdef OT_USE_STD_ITERATOR_BASE
	: public std::iterator<std::bidirectional_iterator_tag, Character>
#endif //OT_USE_STD_ITERATOR_BASE
{
public:

#ifndef OT_USE_STD_ITERATOR_BASE
	typedef std::bidirectional_iterator_tag  iterator_category;
	typedef Character                        value_type;
	typedef ptrdiff_t                        difference_type;
	typedef Character&                       reference;
	typedef CharType*                        pointer;
#endif //OT_USE_STD_ITERATOR_BASE
	
	StringIterator();
	StringIterator(const CharType* ptr);
	StringIterator& operator=(const CharType* ptr);

	bool operator==(const StringIterator& rhs) const;
	bool operator!=(const StringIterator& rhs) const;

	StringIterator& operator++();
	StringIterator operator++(int);
	StringIterator& operator--();
	StringIterator operator--(int);

	Character operator*() const;
	const CharType* data() const;

private:
	const CharType* m_ptr;
};

OT_BASE_NAMESPACE_END

#if OT_BASE_INCLUDE_INLINES
	#include "StringIterator.inl"
#endif

#endif //OT_BASE_StringIterator_h
