//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:43 $
//
//==============================================================================

#ifndef OT_BASE_StringUtils_h
#define OT_BASE_StringUtils_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "ArrayAutoPtr.h"
#include "String.h"

#if defined(WIN32)
	#include "winincl.h"
#endif //WIN32

#include <functional>

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG StringUtils
{
public:
	enum eStripType {leading, trailing, both};
	
	static int CompareNoCase(const String& lhs, const String& rhs);
	static int CompareNoCase(const char* pszLHS, const char* pszRHS);
	static bool LessNoCase(const String& lhs, const String rhs);

	static ByteString ToAscii(const String& str);
	static ByteString ToLatin1(const String& str);
	static ByteString ToUTF8(const String& str);

	static String ToUpper(const String& str);
	static String ToLower(const String& str);
	static String ToHexString(const String& str);

	static String FromNativeMBCS(const char* pStr);
	static ByteString ToNativeMBCS(const String& str);

	static String FromConsoleMBCS(const char* pStr);
	static ByteString ToConsoleMBCS(const String& str);

	static String FromLatin1(const char* pStr);
	static String FromLatin1(const char* pStr, size_t len);
	static String FromLatin1(const ByteString& str);
	static String FromUTF8(const ByteString& str);

	static bool ContainsMultiCharSequence(const String& str);
	static bool ReplaceAll(String& in, CharType search, const String& replacement);
	static bool ReplaceAll(String& in, const String& search, const String& replacement);
	static String StripWhiteSpace(const String& in, eStripType type);
	static String NormalizeWhiteSpace(const String& in);
	static bool IsHexString(const ByteString& in);
	
	static ByteString Format(const char* format, ...);

#ifndef OT_WCHAR
	typedef ArrayAutoPtr< wchar_t > WCharAutoPtr;
	static WCharAutoPtr ToWideChar(const String& str);
#endif //OT_WCHAR

#if defined(WIN32)
	typedef ArrayAutoPtr< TCHAR > TCharAutoPtr;
	static TCharAutoPtr ToWin32String(const String& str);
	static String FromWin32String(LPCTSTR lpStr);
	static String FromMBCSCodePage(const char* pStr, int codepage);
	static ByteString ToMBCSCodePage(const String& str, int codepage);
#endif //WIN32

private:
	StringUtils(); // not implemented
};

OT_BASE_NAMESPACE_END

#endif //OT_BASE_StringUtils_h

