//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/28 19:49:05 $
//
//==============================================================================
//
// Class: SynchronizedObject
// 
//==============================================================================

#ifndef OT_BASE_SynchronizedObject_h
#define OT_BASE_SynchronizedObject_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "AutoLock.h"
#include "ManagedObject.h"
#include "RecursiveMutex.h"

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG SynchronizedObject : public virtual ManagedObject
{
public:

	/**
	Type used to create scoped locks when the lifetime of the
	SynchronizedObject is guaranteed to exceed the locked scope.
	*/
	typedef AutoLock<SynchronizedObject> Lock;

protected:
	friend class AutoLock<SynchronizedObject>;
	friend class Monitor;
	
	void lock();
	void unlock();

private:
#ifdef OT_MT
	RecursiveMutex m_mutex;
#endif //OT_MT
};

//
// Macro to aid in the creation of scoped synchronization locks
//
#ifdef OT_MT

	#define OT_SYNCHRONIZED\
		SynchronizedObject::Lock _scoped_lock_(const_cast<SynchronizedObject&>(*(static_cast<const SynchronizedObject*>(this))));

	#define OT_SYNCHRONIZED_PTR(_LOCK_PTR)\
		OT_DBG_ASSERT(_LOCK_PTR!=0);\
		SynchronizedObject* _p_object_ = _LOCK_PTR;\
		SynchronizedObject::Lock _scoped_lock_(*_p_object_);

	#define OT_SYNCHRONIZED_PTR_ADD(_LOCK_PTR)\
		OT_DBG_ASSERT(_LOCK_PTR!=0);\
		SynchronizedObject* _p_object_ = _LOCK_PTR;\
		RefPtr<SynchronizedObject> _rp_object_(_p_object_);\
		SynchronizedObject::Lock _scoped_lock_(*_p_object_);

#else

	#define OT_SYNCHRONIZED
	#define OT_SYNCHRONIZED_PTR(_LOCK_PTR)
	#define OT_SYNCHRONIZED_PTR_ADD(_LOCK_PTR)

#endif //OT_MT

OT_BASE_NAMESPACE_END

#endif //OT_BASE_SynchronizedObject_h
