//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/10 21:49:03 $
//
//==============================================================================
//
// Class: System
// 
// Overview
// --------
// The System class is a well-known and accessible class module
// that provides access to important system information. . It cannot be
// instantiated - all methods are static.
//
//==============================================================================

#ifndef OT_BASE_System_h
#define OT_BASE_System_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "String.h"
#include "RefPtr.h"

OT_BASE_NAMESPACE_BEGIN

class ObjectManager;
class MessageFactory;

class OT_BASE_PKG System
{
public:

	static ObjectManager& GetObjectManager();

	static String GetAppMessage(const String& org, const String& app,
	                            size_t messageID, const char* szDefault);

	static String GetSysMessage(const String& lib,
	                            size_t messageID, const char* szDefault);

	static RefPtr<MessageFactory> GetMessageFactory();
	static void SetMessageFactory(MessageFactory* pFactory);

	static void Terminate();

	static const String& GetLineEnding();
	static String GetEnvironmentString(const String& name);
	static String GetVersionAsString();
	static unsigned long GetVersion();

	static String GetProperty(const String& name, const String& defaultValue);
	static String GetProperty(const String& name);
	static long GetPropertyLong(const String& name, long defaultValue);
	static bool GetPropertyBool(const String& name, bool bDefault);

	static void SetProperty(const String& name, const String& value);
	static void SetPropertyLong(const String& name, long value);
	static void SetPropertyBool(const String& name, bool bSet);

private:
	System(); // not implemented

	static ObjectManager * OT_MT_VOLATILE s_pObjectManager;
	static MessageFactory * OT_MT_VOLATILE s_pMessageFactory;
};

OT_BASE_NAMESPACE_END

#endif //OT_BASE_System_h

