//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:44 $
//
//==============================================================================
//
// Class: SystemCodeConverter
// 
// Overview
// --------
// The SystemCodeConverter class is a well-known and accessible class module
// that provides access to important routines for translating internal character
// sequences to unicode characters and visa versa.
//
//==============================================================================

#ifndef OT_BASE_SystemCodeConverter_h
#define OT_BASE_SystemCodeConverter_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "CodeConverterBase.h"
#include "String.h"

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG SystemCodeConverter : public CodeConverterBase
{
public:

	static Result ToInternalEncoding(UCS4Char ch, CharType*to, const CharType*to_limit, CharType*& to_next);
	static String ToInternalEncoding(UCS4Char ch);
	static Result FromInternalEncoding(UCS4Char& ch, const CharType* from, const CharType* from_end, const CharType*& from_next);
	static String GetInternalEncodingName();
	static bool IsSequenceStartChar(UCharType ch);
	static size_t GetCharSequenceLength(UCharType ch);
	static size_t GetMaximumCharSequenceLength();
	static Result TestEncodedSequence(const CharType* from, const CharType* from_end, const CharType*& from_next);
	static bool IsValidCharSequence(const CharType* from, size_t len);
};

OT_BASE_NAMESPACE_END

// Include inline functions
#if OT_BASE_INCLUDE_INLINES
	#include "SystemCodeConverter.inl"
#endif

#endif //OT_BASE_SystemCodeConverter_h
