//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/10 21:49:03 $
//
//==============================================================================

#ifndef OT_BASE_Tracer_h
#define OT_BASE_Tracer_h

#ifndef OT_BASE_defs_h
#include "defs.h"
#endif //OT_BASE_defs_h

#include "ManagedObject.h"
#include "String.h"

OT_BASE_NAMESPACE_BEGIN

class OT_BASE_PKG Tracer : public virtual ManagedObject
{
public:
	enum Levels {Highest=0,     /*!< important events that are always traced */
	             Exceptions=10, /*!< exception events */
	             High=20,       /*!< high priority events */
	             Medium=40,     /*!< medium priority events */
	             Low=60,        /*!< low-priority events */
	             Min=99         /*!< the lowest priority */
	};

	enum Sections {All=0,       /*!< used to activate all sections */
	               Base=1,      /*!< classes within the top-level @OpenTop namespace */
	               Util=2,      /*!< classes within the util namespace */
	               IO=3,        /*!< classes within the io namespace */
	               Net=4,       /*!< classes within the net namespace */
	               Auxil=9,     /*!< classes within the auxil namespace */
	               XML=10,      /*!< classes within the xml namespace */
	               User=16      /*!< starting value for user-assigned sections */
	};

	static void SetTracer(Tracer* pTracer);
 
	static void Trace(short nSection, short nLevel, const String& message);
	static void Trace(short nSection, short nLevel, const CharType* message, size_t len);
	static void TraceBytes(short nSection, short nLevel, const String& message, const Byte* bytes, size_t len);

	static void Activate(short nSection, short nLevel);
	static bool IsEnabled();
	static void Enable(bool bEnable);
	static const CharType* GetSectionName(short nSection);
	static short GetSectionNumber(const String& section);

protected:
	virtual void doTrace(short nSection, short nLevel, const CharType* message, size_t len)=0;
	virtual void doTraceBytes(short nSection, short nLevel, const String& message, const Byte* bytes, size_t len)=0;
	virtual void doActivate(short nSection, short nLevel)=0;

	virtual const CharType* getUserSectionName(short nSection);
	virtual short getUserSectionNumber(const String& section);

private:
	static Tracer* OT_MT_VOLATILE s_pTracer;
	static OT_MT_VOLATILE bool s_bEnabled;
};

OT_BASE_NAMESPACE_END

#if OT_BASE_INCLUDE_INLINES
	#include "Tracer.inl"
#endif

#endif //OT_BASE_Tracer_h
