//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/05 21:08:54 $
//
//==============================================================================
//
// This file provides detection and work arounds for specific compilers.
//
//==============================================================================

#ifndef OT_BASE_compdefs_h
#define OT_BASE_compdefs_h

#include <string>

#undef OT_USING_DECL_BROKEN
#undef OT_BOOL_IS_TYPEDEF

// defined when the compiler cannot be used
// to import inherited virtual functions into
// the scope of a derived class when the derived
// class already contains an overloaded function 
// with the same name.

//
// GNU C++ compiler quirks
//
#ifdef __GNUC__ 
	// GNU C++
	#if (__GNUC__ < 3 && __GNUC_MINOR__ < 96)
		#define OT_USING_DECL_BROKEN 1
	#endif
	//
	// libstdc++ v2 does not have a #define that we can use
	// to detect its existence.  For this reason we use
	// some heuristics
	// 1) __GLIBCPP__ not defined (it wasn't defined until v3)
	// 2) __BASTRING__ defined in string from libstdc++ v2
	#if !defined(__GLIBCPP__) && defined(__BASTRING__)
		#define OT_BROKEN_C_STR
		#define OT_NO_WSTRING_TYPEDEF
	#endif

#endif //__GNUC__

//
// Borland C++ compiler quirks
//
#ifdef __BORLANDC__
	// Borland C++
	#define OT_USING_DECL_BROKEN 1

#endif //__BORLANDC__

//
// Sun Workshop C++ compiler quirks
//
#ifdef __SUNPRO_CC
	#if __SUNPRO_CC < 0x420
		#error "Unsupported Sun WorkShop compiler version"
	#elif (__SUNPRO_CC == 0x420 || __SUNPRO_CC >= 0x500 && __SUNPRO_CC_COMPAT == 4)
		#define OT_BOOL_IS_TYPEDEF 1
		#define OT_USING_DECL_BROKEN 1
		typedef int bool;
		#undef false
		#undef true
		#define false 0
		#define true 1
		#define typename class
	#endif
#endif //__SUNPRO_CC

//
// HP aCC C++ compiler quirks
//
#ifdef __HP_aCC
	#define OT_USING_DECL_BROKEN 1
#endif //__HP_aCC

#ifdef _MSC_VER
	//
	// STLPort quirks under MS Visual C++
	//
	#ifdef _STLPORT_VERSION
		// std::find_first_of() requires this (in STLPort v4.5.3)
		#define OT_USE_STD_ITERATOR_BASE 1
	#endif //_STLPORT_VERSION

#endif //_MSC_VER

// 
//
#endif // OT_BASE_compdefs_h

