//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:24:48 $
//
//==============================================================================
/**
	@namespace ot

	This is the top-level @OpenTop namespace.  It contains classes that deal with:-
	- object lifetime management and garbage collection
	- multi-threading and synchronization
	- Unicode string encoding, formatting and conversion
	- message text retrieval and internationalization
	- tracing (event logging)

  	The top-level @c ot namespace contains classes that support this general-purpose
	functionality in addition to a number of subordinate namespaces which 
	house classes providing more specialized behaviour.
*/
//==============================================================================

#ifndef OT_BASE_defs_h
#define OT_BASE_defs_h

#include "gendefs.h"
#include "threaddefs.h"

#include <string>

#define OT_BASE_PKG OT_OPENTOP_PKG
#define OT_BASE_INCLUDE_INLINES OT_OPENTOP_INCLUDE_INLINES
#define OT_BASE_NAMESPACE_BEGIN OT_NAMESPACE_BEGIN
#define OT_BASE_NAMESPACE_END   OT_NAMESPACE_END

//
// Under MSVC, automatically link to requirted library
//
#if defined(_MSC_VER) && !defined(OT_IOS_EXPORT)
#include "libname.h"
#pragma comment(lib, OT_LIBNAME(opentop))
#endif

OT_BASE_NAMESPACE_BEGIN

//==============================================================================
//  typedef: CharType
/**
	Determines the character type used by @OpenTop.

    The type is set equal to the value of the pre-processor symbol @c OT_CHAR_TYPE
	which is set equal to @c char unless the @c OT_WCHAR pre-processor
	symbol is specified, in which case it is set to @c wchar_t.

    As @c char is normally only 8-bits wide and @c wchar_t is only 16-bits wide
	on some platforms, it is not always possible to store a Unicode character
	into one ::CharType character.  In this case @OpenTop represents Unicode
	characters using a multi-character encoding.
	
	If ::CharType is @c char then the internal encoding used is UTF-8.  
	If ::CharType is a 16-bit @c wchar_t then UTF-16 is used (not UCS-2).
	If ::CharType is a 32-bit value then no encoding is required as characters are
	UCS4 already.
*/
//==============================================================================
typedef OT_CHAR_TYPE  CharType;

//==============================================================================
//  typedef: UCharType
/**
    Unsigned version of ::CharType. 

    As ::CharType is supposed to represent character values, ideally it should
	be an unsigned value.  This is the case on some platforms but not on others.
	Functions that must use an unsigned value use ::UCharType in place of ::CharType.

	On platforms where ::CharType is already unsigned, ::CharType and ::UCharType 
	represent the same type.
*/
//==============================================================================
typedef OT_UCHAR_TYPE UCharType;

//==============================================================================
//  typedef: Byte
/**
	Represents a byte which is an unsigned 8-bit value with a range of 0-255.
	
	Bytes are used as the value type when reading or writing external media
	or communicating with other systems.  Bytes are typically converted to and
	from characters using some form of encoding.
*/
//==============================================================================
typedef unsigned char Byte;

//==============================================================================
//  typedef: UCS4Char
/**
	Represents an integer type that is capable of holding the code-points for
	all Unicode characters in the range U+0000 to U+10FFFF.
	
    This range requires an integer at least 21 bits wide, so @c UCS4Char is normally
	implemented using a 32-bit value.

    On some platforms (such as Linux) @c wchar_t is a 32-bit integer, so @c 
	UCS4Char and @c wchar_t are the same.  However, on other platforms (such
	as Microsoft Windows) @c wchar_t is a 16-bit integer and is therefore 
	incapable of representing the required Unicode range.
*/
//==============================================================================
typedef unsigned long UCS4Char;

//==============================================================================
//  typedef: UShort
/**
	Convenient type used as an unsigned short integer.
*/
//==============================================================================
typedef unsigned short UShort;

//==============================================================================
//  typedef: IntType
/**
	Type used as the return type in operations that need to return either
	a ::CharType or -1 which might not be a legal ::CharType value.
*/
//==============================================================================
typedef OT_INT_TYPE IntType;

OT_BASE_NAMESPACE_END

#endif //OT_BASE_defs_h

