//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.4 $
// $Date: 2003/09/10 20:19:22 $
//
//==============================================================================
//
// This file provides general macros that are required by the OpenTop Library
//
//==============================================================================

#ifndef OT_BASE_gendefs_h
#define OT_BASE_gendefs_h

//
// Include OpenTop version flags
//
#include "version.h"

//
// Include the top-level configuration header
//
#ifdef WIN32
	#include "winconfig.h"
#else
	#include "config.h"
#endif

#ifdef _MSC_VER
	// disable annoying template warning under msvc
	#pragma warning(disable: 4786)
	// disable 'this' pointer used in member initialization message
	#pragma warning(disable: 4355)
	// disable 'need to have dll interface to be used by clients' message
	#pragma warning(disable: 4251)
#endif

//
// Include compiler-specific feature detection
//
#include "compdefs.h"

//
// If OpenTop is to be compiled against "standard compliant" systems, then
// the following macros should be defined.  Note, however, that this
// has an impact on the library names that must be linked with the application
// and is therefore not necessarily desirable.
//
//#define _XOPEN_SOURCE            500 // Specified by the "Single UNIX specification"
//#define _XOPEN_SOURCE_EXTENDED   1   // UNIX 98 socket behaviour on HP-UX
//#define _SVID_SOURCE             1   // ISO C, POSIX, and SVID things (gethostbyname_r)

//#include <stdlib.h>  // NULL etc
#include <stddef.h>  // ANSI types and functions

// ensure agreement between various flavours of DEBUG macro
#if defined(_DEBUG) && !defined(DEBUG)
	#define DEBUG
#endif //defined

#if defined(DEBUG) && !defined(_DEBUG)
#define _DEBUG
#endif //defined

#ifdef OT_MT
	#ifdef WIN32
		#define OT_WIN32_THREADS
	#else
		#define OT_POSIX_THREADS
	#endif
#endif //OT_MT

// ensure agreement between various flavours of multi-threaded options
#if defined(OT_MT) && !defined(_REENTRANT)
	#define _REENTRANT
#endif //defined

//
// Allow the OpenTop namespace name to be set externally if required
//
#ifndef OT_NAMESPACE_NAME
	#define OT_NAMESPACE_NAME ot
#endif

#define OT_NAMESPACE_BEGIN \
namespace OT_NAMESPACE_NAME {

#define OT_NAMESPACE_END \
} /* end of namespace */

#define OT_SUB_NAMESPACE_BEGIN(N) \
OT_NAMESPACE_BEGIN \
namespace N {

#define OT_SUB_NAMESPACE_END(N) \
}} /* end of namespaces */

//
// OpenTop is currently configured to use either char or wchar_t as its
// character type.  The default is char, but wchar_t is selected if the OT_WCHAR
// macro is defined
//
#ifndef OT_DOCUMENTATION_ONLY

#ifdef OT_WCHAR
	#define OT_CHAR_TYPE wchar_t

	// If the platform's wchar_t is unsigned, then we use that as our
	// UCharType, otherwise we use unsigned
	#ifdef HAVE_UNSIGNED_WCHAR_T
		#define OT_UCHAR_TYPE wchar_t
	#else
		#define OT_UCHAR_TYPE unsigned
	#endif

	#define OT_INT_TYPE int
	#define OT_T(t) L##t

	#ifdef OT_UCS2
		#if SIZEOF_WCHAR_T < 2
			#error UCS2 requires at least 16 bits
		#endif

		#define OT_MAX_CHAR 0xFFFE
		#undef  OT_UCS4
		#undef  OT_UTF16

	#else // !OT_UCS2

		#define OT_MAX_CHAR 0x10FFFF
		#if SIZEOF_WCHAR_T == 2
			#define OT_UTF16
			#undef OT_UCS4
		#elif SIZEOF_WCHAR_T >= 4
			#define OT_UCS4
			#undef OT_UTF16
		#else
			#error unsupported wchar_t size
		#endif //SIZEOF_WCHAR_T

	#endif // !OT_UCS2

	//#define OT_COUT std::wcout
	//#define OT_CERR std::wcerr

#else  // !OT_WCHAR

	#define OT_CHAR_TYPE char
	#define OT_UCHAR_TYPE unsigned char
	#define OT_INT_TYPE int
	#define OT_T(t) t
	#define OT_MAX_CHAR 0x10FFFF
	#define OT_UTF8
	#undef  OT_UTF16
	#undef  OT_UCS4
	#undef  OT_UCS2
	//#define OT_COUT std::cout
	//#define OT_CERR std::cerr

#endif //OT_WCHAR
#endif //OT_DOCUMENTATION_ONLY

//
// Win32 DLL Versions of the library
//
#if defined(WIN32) && defined(OT_DLL)
	#if defined OT_IOS_EXPORT
		#define OT_OPENTOP_PKG __declspec(dllexport)
		#define OT_OPENTOP_INCLUDE_INLINES 1
	#else
		#define OT_OPENTOP_PKG __declspec(dllimport)
		#if defined(_MSC_VER) && 1300 <= _MSC_VER
			#define OT_OPENTOP_INCLUDE_INLINES 0
		#else
			#define OT_OPENTOP_INCLUDE_INLINES 1
		#endif
	#endif
#else
	#define OT_OPENTOP_PKG
	#define OT_OPENTOP_INCLUDE_INLINES 1
#endif

#endif // OT_BASE_gendefs_h

