//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.3 $
// $Date: 2003/08/10 21:49:03 $
//
//==============================================================================

#ifndef OT_BASE_threaddefs_h
#define OT_BASE_threaddefs_h

#ifdef OT_MT

	#if defined(OT_WIN32_THREADS)

		#include "winincl.h"
	
		// windows.h has an unfortunate habit of #defining Yield()
		#ifdef Yield
			#undef Yield
		#endif

	#elif defined(OT_POSIX_THREADS)

		#include <pthread.h>

	#else

		#error "OT_MT defined but no threading support available"

	#endif

	//
	// Macros to aid in the creation of scoped mutex locks
	//
	#define OT_AUTO_LOCK(_LOCK_TYPE, _THE_LOCK)\
		_LOCK_TYPE::Lock _scoped_lock_((_LOCK_TYPE&)_THE_LOCK)

	#define OT_MT_VOLATILE volatile

#else // !OT_MT

	#define OT_AUTO_LOCK(_LOCK_TYPE, _THE_LOCK)
	#define OT_MT_VOLATILE

#endif // OT_MT

#endif // OT_BASE_threaddefs_h
