//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:01 $
//
//==============================================================================
//
// Class: CodeConverter
// 
//=============================================================================

#ifndef OT_CVT_CodeConverter_h
#define OT_CVT_CodeConverter_h

#ifndef OT_CVT_defs_h
#include "defs.h"
#endif //OT_CVT_defs_h

#include "ot/base/CodeConverterBase.h"

OT_CVT_NAMESPACE_BEGIN

class OT_CVT_PKG CodeConverter : public virtual ManagedObject, public CodeConverterBase
{
public:
    
	enum CharAction {abort   /** throw exception when error detected*/,
	                 replace /** use a replacement character */
	};

	CodeConverter();

    virtual Result decode(const Byte *from, const Byte *from_end,
	                      const Byte *& from_next,
	                      CharType *to, CharType *to_limit,
	                      CharType *& to_next);

	virtual Result encode(const CharType *from, const CharType *from_end,
	                      const CharType *& from_next,
	                      Byte *to, Byte *to_limit,
	                      Byte *& to_next);

	virtual size_t getDecodedLength(const Byte *from, const Byte *from_end) const;

	virtual size_t getMaxEncodedLength() const;

	virtual bool alwaysNoConversion() const;

	virtual String getEncodingName() const;

	void setInvalidCharAction(CharAction eAction);
	CharAction getInvalidCharAction() const;
	
	void setInvalidCharReplacement(UCS4Char ch);
	UCS4Char getInvalidCharReplacement() const;

	void setUnmappableCharAction(CharAction eAction);
	CharAction getUnmappableCharAction() const;
	
	void setUnmappableCharReplacement(UCS4Char ch);
	UCS4Char getUnmappableCharReplacement() const;

protected:
	virtual Result handleUnmappableCharacter(UCS4Char ch,
	                                         Byte*  to,
	                                         Byte*  to_limit,
	                                         Byte*& to_next);

	void handleInvalidByteSequence(const Byte* from, size_t len) const;
	void throwUnsupported(unsigned long illegalChar) const;
	void internalEncodingError(const CharType* from, size_t len) const;

private:
	void cannotEncodeChar(UCS4Char ch) const;

private:
	UCS4Char m_invalidCharReplacement;
	CharAction m_invalidCharAction;
	UCS4Char m_unmappableCharReplacement;
	CharAction m_unmappableCharAction;
};

OT_CVT_NAMESPACE_END

#endif //OT_CVT_CodeConverter_h
