//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:05 $
//
//==============================================================================
//
// Class: Simple8BitConverter
// 
// Overview
// --------
// Provides a version of a CodeConverter that can encode/decode ISO-8859-1
// byte streams.
//
//=============================================================================

#ifndef OT_CVT_Simple8BitConverter_h
#define OT_CVT_Simple8BitConverter_h

#ifndef OT_CVT_defs_h
#include "defs.h"
#endif //OT_CVT_defs_h

#include "CodeConverter.h"
#include <map>

OT_CVT_NAMESPACE_BEGIN

class OT_CVT_PKG Simple8BitConverter : public CodeConverter
{

public:

	typedef unsigned short CodedChar;

	Simple8BitConverter(const String& name,
	                    const CodedChar* decodingTable);

    virtual Result decode(const Byte *from, const Byte *from_end,
	                     const Byte *& from_next,
	                     CharType *to, CharType *to_limit,
	                     CharType *& to_next);

	virtual Result encode(const CharType *from, const CharType *from_end,
	                     const CharType *& from_next,
	                     Byte *to, Byte *to_limit,
	                     Byte *& to_next);

	virtual size_t getDecodedLength(const Byte *from, const Byte *from_end) const;

	virtual size_t getMaxEncodedLength() const;

	virtual bool alwaysNoConversion() const;

	virtual String getEncodingName() const;

protected:
	void generateEncodingMap();

private:
	typedef std::map<CodedChar, Byte, std::less<CodedChar> > EncodingMap;
	EncodingMap m_encodingMap;
	const CodedChar* m_pDecodingTable;
	String m_name;
};

OT_CVT_NAMESPACE_END

#endif //OT_CVT_Simple8BitConverter_h
