//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:06 $
//
//==============================================================================
//
// Class: UTF8codecvt
// 
// Overview
// --------
// Provides a version of a std::codecvt that will encode/decode UTF-8
// byte streams.
//
//=============================================================================

#ifndef OT_CVT_UTF8codecvt_h
#define OT_CVT_UTF8codecvt_h

#ifndef OT_CVT_defs_h
#include "defs.h"
#endif //OT_CVT_defs_h

#include <locale>
#include "UTF8Converter.h"

OT_CVT_NAMESPACE_BEGIN

class UTF8codecvt : public std::codecvt<CharType, char, mbstate_t>
{
public:
	typedef std::codecvt<CharType, char, mbstate_t> codecvt_base;
    typedef CharType internT;
    typedef Byte externT;
    typedef mbstate_t stateT;

    explicit UTF8codecvt(size_t refs = 0)
        : codecvt_base(refs) {}

protected:
    virtual result do_in(stateT& state,
	                     const externT *from, const externT *from_end,
	                     const externT *& from_next,
	                     internT *to, internT *to_limit,
	                     internT *& to_next) const;

	virtual result do_out(stateT& state,
	                     const internT *from, const internT *from_end,
	                     const internT *& from_next,
	                     externT *to, externT *to_limit,
	                     externT *& to_next) const;

    virtual result do_unshift(stateT& state,
	                     externT *to, externT *to_limit, externT *& to_next) const;

    virtual int do_length(stateT& state, const externT *from,
	                     const externT *from_end, size_t max) const;

	virtual bool do_always_noconv() const;

	virtual int do_max_length() const;

	virtual int do_encoding() const;

private:
	UTF8Converter m_cvt;
};

OT_CVT_NAMESPACE_END

#endif //OT_CVT_UTF8codecvt_h
