//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:10 $
//
//==============================================================================
//
// Class: BufferedOutputStream
// 
//==============================================================================

#ifndef OT_IO_BufferedOutputStream_h
#define OT_IO_BufferedOutputStream_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "OutputStream.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG BufferedOutputStream : public OutputStream
{
public:

	BufferedOutputStream(OutputStream* pOutputStream);
	BufferedOutputStream(OutputStream* pOutputStream, size_t bufSize);
	virtual ~BufferedOutputStream();

	virtual void close();
	virtual void flush();
	virtual void flushBuffers();

#ifdef OT_USING_DECL_BROKEN
	virtual void write(Byte x) {OutputStream::write(x);}
#else
	using OutputStream::write; 	// unhide inherited write method
#endif

	virtual void write(const Byte* pBuffer, size_t bufLen);

private:
	BufferedOutputStream(const BufferedOutputStream& rhs);            // cannot be copied
	BufferedOutputStream& operator=(const BufferedOutputStream& rhs); // nor assigned

	void init(size_t bufferSize);
	void freeBuffers();
	void writeBuffer();

private:
	Byte*  m_pBuffer;
	size_t m_bufferSize;
	size_t m_used;
	RefPtr<OutputStream> m_rpOutputStream;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_BufferedOutputStream_h
