//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:10 $
//
//==============================================================================
//
// Class: BufferedReader
// 
//=============================================================================

#ifndef OT_IO_BufferedReader_h
#define OT_IO_BufferedReader_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "Reader.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG BufferedReader : public Reader
{
public:
	BufferedReader(Reader* pReader);
	BufferedReader(Reader* pReader, size_t size);

	virtual ~BufferedReader();

	virtual void mark(size_t readLimit);
	virtual bool markSupported() const;
	virtual void reset();
	virtual void close();

#ifdef OT_USING_DECL_BROKEN
	virtual IntType read() {return Reader::read();}
#else
	using Reader::read; 	// unhide inherited read methods
#endif

	virtual long read(CharType* pBuffer, size_t bufLen);
	virtual long readAtomic(CharType* pBuffer, size_t bufLen);
	virtual Character readAtomic();

	virtual long readLine(String& ret);

private:
	void init(size_t bufSize);
	void fillBuffer();

private:
	CharType* m_pBuffer;
	int m_markPos;
	size_t m_pos;
	size_t m_count;
	size_t m_bufSize;
	bool m_eof;
	bool m_bCRSeen;
	RefPtr<Reader> m_rpReader;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_BufferedReader_h
