//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:11 $
//
//==============================================================================

#ifndef OT_IO_ByteArrayInputStream_h
#define OT_IO_ByteArrayInputStream_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "InputStream.h"

#include "ot/base/ArrayAutoPtr.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG ByteArrayInputStream : public InputStream
{
public:
	ByteArrayInputStream(const Byte* pData, size_t dataLen);

	virtual void mark(size_t readLimit);
	virtual bool markSupported() const;
	virtual void reset();
	virtual size_t available();
	virtual void close();

#ifdef OT_USING_DECL_BROKEN
	virtual int read() {return InputStream::read();}
#else
	using InputStream::read; 	// unhide inherited read methods
#endif

	virtual long read(Byte* pBuffer, size_t bufLen);

private:
	ByteArrayInputStream(const ByteArrayInputStream& rhs);            // cannot be copied
	ByteArrayInputStream& operator=(const ByteArrayInputStream& rhs); // nor assigned

private:
	ArrayAutoPtr<Byte> m_apBuffer;
	size_t m_bufSize;
	size_t m_pos;
	int m_markPos;
	bool m_bClosed;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_ByteArrayInputStream_h

