//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:11 $
//
//==============================================================================
//
// Class: ByteArrayOutputStream
// 
//==============================================================================

#ifndef OT_IO_ByteArrayOutputStream_h
#define OT_IO_ByteArrayOutputStream_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "OutputStream.h"

#include "ot/base/AutoBuffer.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG ByteArrayOutputStream : public OutputStream
{
public:
	ByteArrayOutputStream();
	ByteArrayOutputStream(size_t size);

	virtual void close();

#ifdef OT_USING_DECL_BROKEN
	virtual void write(Byte x) {OutputStream::write(x);}
#else
	using OutputStream::write; 	// unhide inherited write method
#endif

	virtual void write(const Byte* pBuffer, size_t bufLen);

	void reset();
	void writeTo(OutputStream* pOut) const;
	size_t size() const;
	String toString(const String& encoding) const;
	String toString(CodeConverter* pDecoder) const;
	String toString() const;
	const Byte* data() const;

private:
	ByteArrayOutputStream(const ByteArrayOutputStream& rhs);            // cannot be copied
	ByteArrayOutputStream& operator=(const ByteArrayOutputStream& rhs); // nor assigned

	AutoBuffer<Byte> m_buffer;
	bool m_bClosed;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_ByteArrayOutputStream_h
