//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:11 $
//
//==============================================================================
// Class: CharacterCodingException
// 
/**
	@class ot::io::CharacterCodingException
	
	@brief Base class for encoding exceptions.
	       
	Derived exceptions are thrown when an InputStreamReader reads
	a malformed byte sequence or when an OutputStreamWriter attempts
	to write a Unicode character that cannot be mapped into the
	output encoding.
*/
//==============================================================================

#ifndef OT_IO_CharacterCodingException_h
#define OT_IO_CharacterCodingException_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "IOException.h"
#include "ot/cvt/CodeConverter.h"

OT_IO_NAMESPACE_BEGIN

using cvt::CodeConverter;

class OT_IO_PKG CharacterCodingException : public IOException
{
public:
	/** Constructs a CharacterCodingException with a decoder.
	* @param pDecoder the CodeConverter giving rise to the exception
	*/
	CharacterCodingException(CodeConverter* pDecoder) :
		m_rpDecoder(pDecoder)
	{}

	/** Constructs a CharacterCodingException with a detail message and
	*   a decoder.
	* @param message the detail message
	* @param pDecoder the CodeConverter giving rise to the exception
	*/
	CharacterCodingException(const String& message, CodeConverter* pDecoder) : 
		IOException(message),
		m_rpDecoder(pDecoder)
	{}

	virtual String getExceptionType() const {return OT_T("CharacterCodingException");}

	/** Returns a reference to the CodeConverter that gave rise 
	*   to the exception.
	*   This may be used to change the policy of the CodeConverter before
	*   retrying the operation.
	*/
	RefPtr<CodeConverter> getCodeConverter() const {return m_rpDecoder;}

private:
	RefPtr<CodeConverter> m_rpDecoder;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_CharacterCodingException_h

