//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:13 $
//
//==============================================================================

#ifndef OT_IO_File_h
#define OT_IO_File_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "FileSystem.h"
#include "ot/util/DateTime.h"

#include <list>

OT_IO_NAMESPACE_BEGIN

using util::DateTime;

class OT_IO_PKG File
{
public:
	File(const File& parent, const String& child);
	File(const String& pathname);
	File(const String& parent, const String& child);
	File(const File& rhs);
	
	bool operator==(const File& rhs) const;
	bool operator!=(const File& rhs) const;
	
	bool canRead() const;
	bool canWrite() const;
	void deleteFile() const;
	bool exists() const;
	String getAbsolutePath() const;
	String getCanonicalPath() const;
	DateTime lastModified() const;
	String getName() const;
	String getParent() const;
	File getParentFile() const;
	String getPath() const;
	bool isAbsolute() const;
	bool isDirectory() const;
	bool isFile() const;
	size_t length() const;
	std::list<String> listDirectory() const;
	void createNewFile() const;
	void mkdir() const;
	void mkdirs() const;
	void renameTo(const File& file) const;

	void setLastModified(const DateTime& time) const;
	void setReadOnly(bool bReadOnly) const;

	static CharType GetSeparatorChar();
	static String GetSeparator();
	static String GetCurrentDirectory();

	static String GetCanonicalPath(const String& path);

private: // implementation routines

	static String NormalizePath(const String& path);
	static bool IsAbsolutePath(const String& path);

private: // not implemented
	File& operator=(const File& rhs);

private: // member variables
	RefPtr<FileSystem> m_rpFS;
	String m_path;
	size_t m_prefixLength;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_File_h

