//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/10 22:12:39 $
//
//==============================================================================
//
// Class: FileOutputStream
// 
//==============================================================================

#ifndef OT_IO_FileOutputStream_h
#define OT_IO_FileOutputStream_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "OutputStream.h"
#include "FileDescriptor.h"

OT_IO_NAMESPACE_BEGIN

class File;

class OT_IO_PKG FileOutputStream : public OutputStream
{
public:
	FileOutputStream(const File& file);
	FileOutputStream(const String& name);
	FileOutputStream(const String& name, bool bAppend);
	FileOutputStream(FileDescriptor* pFD);

	virtual void close();

#ifdef OT_USING_DECL_BROKEN
	virtual void write(Byte x) {OutputStream::write(x);}
#else
	using OutputStream::write; 	// unhide inherited write method
#endif

	virtual void write(const Byte* pBuffer, size_t bufLen);
	
	RefPtr<FileDescriptor> getFD() const;

private:
	FileOutputStream(const FileOutputStream& rhs);            // cannot be copied
	FileOutputStream& operator=(const FileOutputStream& rhs); // nor assigned

	void open(const String& fileName, bool bAppend);

private:
	RefPtr<FileDescriptor> m_rpFD;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_FileOutputStream_h



