//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/10 22:08:41 $
//
//==============================================================================

#ifndef OT_IO_FileSystem_h
#define OT_IO_FileSystem_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "FileDescriptor.h"
#include <list>

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG FileSystem : public virtual ManagedObject
{
public:

	enum {EndOfFile=-1 /*!< end of file reached */ };

	static RefPtr<FileSystem> GetFileSystem();
	static void SetFileSystem(FileSystem* pFileSystem);

	virtual String getCurrentDirectory() const=0;
	virtual String getSeparator() const;
	virtual CharType getSeparatorChar() const=0;
	virtual String normalize(const String& path) const;
	virtual size_t getPrefixLength(const String& path) const=0;
    virtual String resolve(const String& path) const;
	virtual String resolve(const String& parent, const String& child) const;
    virtual bool isAbsolute(const String& path) const=0;
	virtual bool isCaseSensitive() const=0;
	virtual String canonicalize(const String& path) const;
	
	enum Attribute {Exists      = 0x01 /*!< File exists */,
	                RegularFile = 0x02 /*!< A regular file i.e. not a directory */,
	                Directory   = 0x04 /*!< File is a directory */,
	                Hidden      = 0x08 /*!< File is hidden */,
					ReadOnly    = 0x10 /*!< File is read-only for the current process */};

	virtual int getFileAttributeFlags(const String& path) const=0;

	enum AccessMode {ReadAccess  = 0x01 /*!< Request read access */,
	                 WriteAccess = 0x02 /*!< Request write access */};

	virtual bool checkAccess(const String& path, AccessMode mode) const=0;

	virtual DateTime getLastModifiedTime(const String& path) const=0;
	virtual size_t getLength(const String& path) const=0;

	enum CreationDisp {OpenExisting         /*!< open existing file only */,
	                   OpenCreateAppend     /*!< open existing or create new, preserve existing contents */,
	                   OpenCreateExclusive  /*!< create non-existing file only */,
	                   OpenCreateTruncate   /*!< open existing or create new, destroy existing contents */ };

	virtual RefPtr<FileDescriptor> openFile(const String& path,
	                                        int accessMode,
	                                        CreationDisp creationDisp,
	                                        int attributes) const=0;

	virtual void closeFile(FileDescriptor* pFD) const=0;
    virtual void deleteFile(const String& path) const=0;
	virtual std::list<String> listDirectory(const String& path) const=0;
	virtual void createDirectory(const String& path) const=0;
	virtual void rename(const String& path1, const String& path2) const =0;
	virtual void setLastModifiedTime(const String& path, const DateTime& time) const =0;
	virtual void setReadOnly(const String& path, bool bReadOnly) const =0;

	enum ConsoleStream {Stdin  = 0   /*!< standard input */,
	                    Stdout = 1   /*!< standard output */,
						Stderr = 2   /*!< standard error */};

	virtual RefPtr<FileDescriptor> getConsoleFD(ConsoleStream stream) const =0;
	virtual size_t readFile(FileDescriptor* pFD, Byte* pBuffer, size_t bufLen) const =0;
	virtual void writeFile(FileDescriptor* pFD, const Byte* pBuffer, size_t bufLen) const =0;

private:
	static FileSystem* OT_MT_VOLATILE s_pFileSystem;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_FileSystem_h

