//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:16 $
//
//==============================================================================
//
// Class: FilterReader
// 
// Overview
// --------
// Based on the java.io.FilterReader class.  Provides a base class
// for reading filtered character streams. 
//
// All methods in this implementation delegate directly to the contained
// Reader.  Subclasses should override methods as appropriate.
//
//=============================================================================

#ifndef OT_IO_FilterReader_h
#define OT_IO_FilterReader_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "Reader.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG FilterReader : public Reader
{
public:

	FilterReader(Reader* pReader);

	virtual void close();
	virtual void mark(size_t readLimit);
	virtual bool markSupported() const;
	virtual IntType read();
	virtual long read(CharType* pBuffer, size_t bufLen);
	virtual long readAtomic(CharType* pBuffer, size_t bufLen);
	virtual Character readAtomic();
	virtual void reset();
	virtual size_t skip(size_t n);
	virtual size_t skipAtomic(size_t n);

protected:
	RefPtr<Reader> getReader() const;

private:
	RefPtr<Reader> m_rpReader;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_FilterReader_h

