//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:18 $
//
//==============================================================================
//
// Class: InputStreamReader
// 
//=============================================================================

#ifndef OT_IO_InputStreamReader_h
#define OT_IO_InputStreamReader_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "Reader.h"

OT_IO_NAMESPACE_BEGIN

class InputStream;

class OT_IO_PKG InputStreamReader : public Reader
{
public:

	InputStreamReader(InputStream* pInputStream);
	InputStreamReader(InputStream* pInputStream, const String& encoding);
	InputStreamReader(InputStream* pInputStream, const String& encoding, bool bStrict);
	InputStreamReader(InputStream* pInputStream, CodeConverter* pDecoder);

	virtual ~InputStreamReader();

	virtual void close();

#ifdef OT_USING_DECL_BROKEN
	virtual IntType read() {return Reader::read();}
#else
	using Reader::read; 	// unhide inherited read methods
#endif

	virtual long read(CharType* pBuffer, size_t bufLen);
	virtual long readAtomic(CharType* pBuffer, size_t bufLen);
	virtual Character readAtomic();

	String getEncoding() const;
	RefPtr<CodeConverter> getDecoder() const;

public: // static methods
	static String SenseEncoding(InputStream* pInputStream, size_t& BOMSize);

private: // private helper methods
	InputStreamReader(const InputStreamReader& rhs); // not implemented
	void operator=(const InputStreamReader& rhs);    // not implemented

	void init(const String& encoding, bool bStrict);
	void initDecoder(CodeConverter* pDecoder);
	void freeBuffers();
	void fillByteBuffer();
	size_t readAndDecode(bool bBlock, CharType* pBuffer, size_t bufLen, bool bAtomicRead);
	bool readDirect(CharType* pBuffer, size_t bufLen, bool bAtomicRead, size_t& charsRead);
	void suspendDecodingOptimization(const Byte* pExtraBytes, size_t extraLen);

private:
	enum {CharSeqBufferSize = 8};
	RefPtr<InputStream> m_rpInputStream;
	RefPtr<CodeConverter> m_rpDecoder;
	Byte* m_pByteBuffer;
	Byte* m_pNextByteAvailable;
	Byte* m_pNextByteFree;
	size_t m_byteBufferSize;
	CharType m_charSeqBuffer[CharSeqBufferSize];
	CharType* m_pCharSeqNext;
	size_t m_charSeqLen;
	bool m_bRequiresDecoding;
	bool m_bAtEof;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_InputStreamReader_h

