//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:19 $
//
//==============================================================================

#ifndef OT_IO_OutputStreamWriter_h
#define OT_IO_OutputStreamWriter_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "Writer.h"

OT_IO_NAMESPACE_BEGIN

class OutputStream;
class CodeConverter;

class OT_IO_PKG OutputStreamWriter : public virtual Writer
{
public:
	OutputStreamWriter(OutputStream* pOutputStream);
	OutputStreamWriter(OutputStream* pOut, const String& encoding);
	OutputStreamWriter(OutputStream* pOut, const String& encoding, bool bStrict);
	OutputStreamWriter(OutputStream* pOut, CodeConverter* pEncoder);

	virtual ~OutputStreamWriter();

	virtual void close();
	virtual void flush();
	virtual void flushBuffers();

#ifdef OT_USING_DECL_BROKEN
	virtual void write(CharType c)           {Writer::write(c);}
	virtual void write(const Character& ch)  {Writer::write(ch);}
	virtual void write(const String& str)    {Writer::write(str);}
#else
	using Writer::write; 	// unhide inherited write methods
#endif

	virtual void write(const CharType* pBuf, size_t len);
	// End of Writer interface

	String getEncoding() const;
	RefPtr<CodeConverter> getEncoder() const;

private:
	OutputStreamWriter(const OutputStreamWriter& rhs); // not implemented
	void operator=(const OutputStreamWriter& rhs);     // not implemented

	void init(const String& encoding, bool bStrictEncoding);
	void initEncoder(CodeConverter* pEncoder);
	void freeBuffers();
	bool doEncoding(const CharType* pBuffer, size_t bufLen);
	void writeByteBuffer();

private:
	RefPtr<OutputStream> m_rpOutputStream;
	RefPtr<CodeConverter> m_rpEncoder;
	Byte* m_pByteBuffer;
	size_t m_byteBufferSize;
	size_t m_byteBufferUsed;
	CharType* m_pCharSeqBuffer;
	size_t m_charSeqBufferUsed;
	bool m_bRequiresEncoding;
	bool m_bAtStart;
};

OT_IO_NAMESPACE_END

#endif //OT_IO_OutputStreamWriter_h
