//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:21 $
//
//==============================================================================

#ifndef OT_IO_PrintWriter_h
#define OT_IO_PrintWriter_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "Writer.h"

OT_IO_NAMESPACE_BEGIN

class OutputStream;

class OT_IO_PKG PrintWriter : public Writer
{
public:

	PrintWriter(OutputStream* pOut, bool bAutoFlush=false);
	PrintWriter(Writer* pWriter, bool bAutoFlush=false);

	virtual ~PrintWriter();

	virtual void close();
	virtual void flush();
	virtual void flushBuffers();

#if defined OT_HAVE_BUILTIN_BOOL
	void print(bool b);
#endif //OT_HAVE_BUILTIN_BOOL

	void print(Character c);
	void print(const CharType* pStr);
	void print(double d);
	void print(float f);
	void print(unsigned long l);
	void print(long l);
	void print(unsigned int i);
	void print(int i);
	void print(const String& s);

	void println();

#if defined OT_HAVE_BUILTIN_BOOL
	void println(bool x);
#endif //OT_HAVE_BUILTIN_BOOL

	void println(Character c);
	void println(const CharType* pStr);
	void println(double d);
	void println(float f);
	void println(int i);
	void println(unsigned int i);
	void println(long l);
	void println(unsigned long l);
	void println(const String& s);

#ifdef OT_USING_DECL_BROKEN
	virtual void write(CharType c)           {Writer::write(c);}
	virtual void write(const Character& ch)  {Writer::write(ch);}
	virtual void write(const String& str)    {Writer::write(str);}
#else
	using Writer::write; 	// unhide inherited write methods
#endif

	virtual void write(const CharType* pStr, size_t len);

	//
	// Standard IO Operators
	// 
	PrintWriter& operator<<(PrintWriter& (*func)(PrintWriter&));
	PrintWriter& operator<<(Character c);
	PrintWriter& operator<<(const CharType* pString);
	PrintWriter& operator<<(double d);
	PrintWriter& operator<<(float f);
	PrintWriter& operator<<(unsigned long l);
	PrintWriter& operator<<(long l);
	PrintWriter& operator<<(unsigned int i);
	PrintWriter& operator<<(int i);
	PrintWriter& operator<<(const String& s);
	#if defined OT_HAVE_BUILTIN_BOOL
		PrintWriter& operator<<(bool x);
	#endif //OT_HAVE_BUILTIN_BOOL

private: // Private helper methods
	void init();

private:
	RefPtr<Writer> m_rpWriter;
	bool m_bAutoFlush;
};

// Standard Manipulators
OT_IO_PKG PrintWriter& endl(PrintWriter& w);
OT_IO_PKG PrintWriter& flush(PrintWriter& w);

OT_IO_NAMESPACE_END

#endif //OT_IO_PrintWriter_h
