//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/10 22:14:04 $
//
//==============================================================================

#ifndef OT_IO_Reader_h
#define OT_IO_Reader_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "ot/base/SynchronizedObject.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG Reader : public SynchronizedObject
{
public:
	enum {EndOfFile = -1 /*!< End of character stream reached */};

	typedef CharType unit_type;
	typedef IntType int_type;

	Reader();
	Reader(SynchronizedObject* pLockObject);

	virtual void close();
	virtual void mark(size_t readLimit);
	virtual bool markSupported() const;
	virtual IntType read();
	virtual long read(CharType* pBuffer, size_t bufLen)=0;
	virtual long readAtomic(CharType* pBuffer, size_t bufLen)=0;
	virtual Character readAtomic()=0;
	virtual void reset();
	virtual size_t skip(size_t n);
	virtual size_t skipAtomic(size_t n);

	RefPtr<SynchronizedObject> getLock() const;

protected:
	RefPtrMember<SynchronizedObject> m_rpLock;

private:
	Reader(const Reader& rhs);            // cannot be copied
	Reader& operator=(const Reader& rhs); // nor assigned
};

OT_IO_NAMESPACE_END

#endif //OT_IO_Reader_h

