//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:22 $
//
//==============================================================================
//
// Class: UnmappableCharacterException
// 
/**
	@class ot::io::UnmappableCharacterException
	
	@brief Thrown when an OutputStreamWriter, that has been configured to abort
	when it encounters unmappable characters, writes a Unicode character that 
	cannot be mapped into the target encoding.

	@sa CodeConverter
*/
//==============================================================================

#ifndef OT_IO_UnmappableCharacterException_h
#define OT_IO_UnmappableCharacterException_h

#ifndef OT_CVT_defs_h
#include "defs.h"
#endif //OT_CVT_defs_h

#include "CharacterCodingException.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG UnmappableCharacterException : public CharacterCodingException
{
public:
	/** Constructs an UnmappableCharacterException with a detail message and
	*   a decoder.
	* @param message the detail message
	* @param pDecoder the CodeConverter giving rise to the exception
	*/
	UnmappableCharacterException(const String& message, CodeConverter* pDecoder) : 
		CharacterCodingException(message, pDecoder)
	{}

	virtual String getExceptionType() const {return OT_T("UnmappableCharacterException");}
};

OT_IO_NAMESPACE_END

#endif //OT_IO_UnmappableCharacterException_h

