//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:23 $
//
//==============================================================================

#ifndef OT_IO_Win32FileSystem_h
#define OT_IO_Win32FileSystem_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "FileSystem.h"

#include "ot/base/ArrayAutoPtr.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG Win32FileSystem : public FileSystem
{
public:

	virtual String getCurrentDirectory() const;
	virtual CharType getSeparatorChar() const;
	virtual size_t getPrefixLength(const String& path) const;
	using FileSystem::resolve;
    virtual String resolve(const String& path) const;
	virtual bool isAbsolute(const String& path) const;
	virtual bool isCaseSensitive() const;
	virtual String canonicalize(const String& path) const;
	virtual int getFileAttributeFlags(const String& path) const;
	bool checkAccess(const String& path, AccessMode mode) const;
	virtual DateTime getLastModifiedTime(const String& path) const;
	virtual size_t getLength(const String& path) const;

	virtual RefPtr<FileDescriptor> openFile(const String& path,
	                                        int accessMode,
	                                        CreationDisp creationDisp,
	                                        int attributes) const;

	virtual void closeFile(FileDescriptor* pFD) const;
    virtual void deleteFile(const String& path) const;
	virtual std::list<String> listDirectory(const String& path) const;
	virtual void createDirectory(const String& path) const;
	virtual void rename(const String& path1, const String& path2) const;
	virtual void setLastModifiedTime(const String& path, const DateTime& time) const;
	virtual void setReadOnly(const String& path, bool bReadOnly) const;
	virtual RefPtr<FileDescriptor> getConsoleFD(ConsoleStream stream) const;
	virtual size_t readFile(FileDescriptor* pFD, Byte* pBuffer, size_t bufLen) const;
	virtual void writeFile(FileDescriptor* pFD, const Byte* pBuffer, size_t bufLen) const;

private:
	typedef ArrayAutoPtr<TCHAR> TCharPtr;
	static TCharPtr GetWin32Filename(const String& path);
	static bool IsNotFoundError(DWORD errCode);
	static void FindExistingFile(const String& path, WIN32_FIND_DATA* pFindData);
	static void TranslateCodeToException(DWORD errCode, const String& msg);
};

OT_IO_NAMESPACE_END

#endif //OT_IO_Win32FileSystem_h
