//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/10 22:14:04 $
//
//==============================================================================
//
// Class: Writer
// 
// Overview
// --------
// Based on the java.io.Writer class.  Provides an abstract base class
// with the capability to write characters (as opposed to bytes).
//
// Abstract class for writing to character streams. The only methods that
// a subclass must implement are write(const CharType* pStr),
// flush(), flushBuffers() and close(). Most subclasses, however, will 
// override some of the methods defined here in order to provide higher
// efficiency, additional functionality, or both. 
//
//=============================================================================

#ifndef OT_IO_Writer_h
#define OT_IO_Writer_h

#ifndef OT_IO_defs_h
#include "defs.h"
#endif //OT_IO_defs_h

#include "ot/base/SynchronizedObject.h"

OT_IO_NAMESPACE_BEGIN

class OT_IO_PKG Writer : public SynchronizedObject
{
public:

	typedef CharType unit_type;

	Writer();
	Writer(SynchronizedObject* pLockObject);

	virtual void close()=0;
	virtual void flush(); 
	virtual void flushBuffers();
	virtual void write(const CharType* pStr, size_t len)=0; 
	virtual void write(CharType c);
	virtual void write(const Character& ch);
	virtual void write(const String& str);

	RefPtr<SynchronizedObject> getLock() const;

protected:
	/**
	* The SynchronizedObject used to control concurrent
	* multi-threaded access to synchronized methods.
	*/
	RefPtrMember<SynchronizedObject> m_rpLock;

private:
	Writer(const Writer& rhs);            // cannot be copied
	Writer& operator=(const Writer& rhs); // nor assigned
};

OT_IO_NAMESPACE_END

#endif //OT_IO_Writer_h
