//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1 $
// $Date: 2003/08/11 20:02:16 $
//
//==============================================================================
//
// class DatagramPacket
//
// A simple class used as the holder of information sent and received via
// a DatagramSocket.
//==============================================================================

#ifndef OT_NET_DatagramPacket_h
#define OT_NET_DatagramPacket_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

OT_NET_NAMESPACE_BEGIN

class InetAddress;

class OT_NET_PKG DatagramPacket
{

public:
	explicit DatagramPacket(size_t bufSize);
	DatagramPacket(Byte* pBuffer, size_t bufSize, bool bAssignBuffer=false);
	DatagramPacket(Byte* pBuffer, size_t bufSize, InetAddress* pAddress, int port=-1, bool bAssignBuffer=false);
	~DatagramPacket();

	Byte* getData() const;
	RefPtr<InetAddress> getAddress() const;
	size_t getLength() const;
	size_t getBufferSize() const;
	int getPort() const;

	void setData(size_t bufSize);
	void setData(Byte* pBuffer, size_t bufSize, bool bAssignBuffer=false);
	void setAddress(InetAddress* pAddress);
	void setLength(size_t length);
	void setPort(int port);

private: // not implemented
	DatagramPacket(const DatagramPacket& rhs);            // cannot be copied
	DatagramPacket& operator=(const DatagramPacket& rhs); // nor assigned

private:
	int                 m_port;
	size_t              m_bufSize;
	size_t              m_dataLength;
	bool                m_bBufferOwner;
	Byte*               m_pBuffer;
	RefPtr<InetAddress> m_rpAddress;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_DatagramPacket_h
