//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/26 20:05:18 $
//
//==============================================================================
//
// Class: DatagramSocket
//
// This class should not need much introduction.  It provides a portable wrapper
// around BSD-Style datagram sockets under Linux/Unix and WinSock 
// datagram sockets under Windows.
//
//==============================================================================

#ifndef OT_NET_DatagramSocket_h
#define OT_NET_DatagramSocket_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "DatagramSocketImpl.h"

OT_NET_NAMESPACE_BEGIN

class InetAddress;
class DatagramSocketImpl;
class DatagramSocketImplFactory;

class OT_NET_PKG DatagramSocket : public virtual ManagedObject 
{
public:
	DatagramSocket();
	DatagramSocket(int port);
	DatagramSocket(int port, InetAddress* pLocalAddr);

	virtual void bind(int port, InetAddress* pLocalAddr);
	virtual void close();
	virtual void connect(InetAddress* pAddress, int port);
	virtual void disconnect();
	virtual bool getBroadcast() const;
	virtual RefPtr<InetAddress> getInetAddress() const;
	virtual RefPtr<InetAddress> getLocalAddress() const;
	virtual int getLocalPort() const;
	virtual int getPort() const;
	virtual int getReceiveBufferSize() const;
	virtual bool getReuseAddress() const;
	virtual int getSendBufferSize() const;
	virtual size_t getSoTimeout() const;
	virtual bool isBound() const;
	virtual bool isClosed() const;
	virtual bool isConnected() const;
	virtual void setBroadcast(bool bBroadcast);
	virtual void setReceiveBufferSize(size_t size);
	virtual void setReuseAddress(bool bEnable);
	virtual void setSendBufferSize(size_t size);
	virtual void setSoTimeout(size_t timeoutMS);
	virtual String toString() const;

	virtual void send(const DatagramPacket& p);
	virtual void receive(DatagramPacket& p);

public: // static methods
	static void SetDatagramSocketImplFactory(DatagramSocketImplFactory* pFac);
	static RefPtr<DatagramSocketImplFactory> GetDatagramSocketImplFactory();

protected:
	void createDatagramSocketImpl();
	RefPtr<DatagramSocketImpl> getDatagramSocketImpl() const;

private:
	RefPtr<DatagramSocketImpl> m_rpDatagramSocketImpl;

	static DatagramSocketImplFactory* OT_MT_VOLATILE s_pDatagramSocketImplFactory;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_DatagramSocket_h
