//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/26 20:03:58 $
//
//==============================================================================

#ifndef OT_NET_DatagramSocketImpl_h
#define OT_NET_DatagramSocketImpl_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

OT_NET_NAMESPACE_BEGIN

class DatagramPacket;
class InetAddress;
class SocketDescriptor;

class OT_NET_PKG DatagramSocketImpl : public virtual ManagedObject
{
	friend class DatagramSocket;
	friend class MulticastSocket;

protected:
	virtual void bind(InetAddress* pAddress, int port)=0;
	virtual void close()=0;
	virtual void connect(InetAddress* pAddress, int port)=0;
	virtual void create()=0;
	virtual void disconnect()=0;

	virtual RefPtr<InetAddress> getInetAddress() const=0;
	virtual RefPtr<InetAddress> getLocalAddress() const=0;

	virtual int getLocalPort() const=0;
	virtual int getPort() const=0;
	virtual RefPtr<SocketDescriptor> getSocketDescriptor() const=0;

	virtual String toString() const=0;

	virtual void send(const DatagramPacket& p)=0;
	virtual void receive(DatagramPacket& p)=0;

	// Socket Option methods
	virtual int getIntOption(int level, int option) const=0;
	virtual void getVoidOption(int level, int option, void* pOut, size_t* pLen) const=0;
	virtual void setIntOption(int level, int option, int value)=0;
	virtual void setVoidOption(int level, int option, void* pValue, size_t valLen)=0;
	virtual size_t getTimeout() const=0;
	virtual void setTimeout(size_t timeoutMS)=0;

	virtual bool isClosed() const=0;
	virtual bool isConnected() const=0;
	virtual bool isBound() const=0;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_DatagramSocketImpl_h
