//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/09/04 21:35:01 $
//
//==============================================================================

#ifndef OT_NET_FtpClient_h
#define OT_NET_FtpClient_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "TcpNetworkClient.h"

#include "ot/io/Writer.h"
#include "ot/io/BufferedReader.h"

OT_NET_NAMESPACE_BEGIN

using io::Writer;
using io::BufferedReader;

class OT_NET_PKG FtpClient : public TcpNetworkClient
{
public:

	enum TransferType { Binary /*!< Treats files an an opaque stream of bytes */,
	                    Ascii  /*!< Translates line-feeds into the appropriate local format */ };

	enum DataConnectionType { Passive /*!< Client connects to the (passive) server for data transfers */,
	                          Active  /*!< (Active) server connects to the client for data transfers */ };

	FtpClient();
	~FtpClient();

	virtual void preDisconnect();

	void login(const String& user, const String& password);

	DataConnectionType getDataConnectionType() const;
	TransferType getTransferType() const;
	size_t getDataConnectionTimeout() const;
	bool getCheckInboundConnection() const;

	String printWorkingDirectory();

	void setTransferType(TransferType type);
	void setDataConnectionType(DataConnectionType type);
	void setDataConnectionTimeout(size_t timeoutMS);
	void setCheckInboundConnection(bool bCheckInboundConnection);

	size_t getFileSize(const String& path);
	bool changeWorkingDirectory(const String& path);
	bool changeToParentDirectory();

	RefPtr<InputStream> listDetails(const String& spec);
	RefPtr<InputStream> listNames(const String& spec);

	RefPtr<InputStream> retrieveFile(const String& path, size_t offset=0);
	void retrieveFile(const String& path, OutputStream* pOut, size_t offset=0);

	RefPtr<OutputStream> storeFile(const String& path, size_t offset=0);
	void storeFile(const String& path, InputStream* pIn, size_t offset=0);

	RefPtr<OutputStream> appendFile(const String& path);
	void appendFile(const String& path, InputStream* pIn);

	void dataTransferComplete();
	void abortDataTransfer();

	void renameFile(const String& from, const String& to);

protected: // Overridden TcpNetworkClient virtual methods
	virtual int getDefaultPort() const;
	virtual void postConnect(const String& server, int port, size_t timeoutMS);

private:
	virtual RefPtr<InputStream> inputDataCommand(const String& command);
	virtual RefPtr<OutputStream> outputDataCommand(const String& command);

	void port(InetAddress* pAddr, int port);
	int syncCommand(const String& command);
	void asyncCommand(const String& command);
	int readCommandResponse();
	void restart(size_t offset);

	void handleInvalidResponse(const String& cmd);
	void handleInvalidFileResponse(const String& cmd, const String& path);

	RefPtr<Socket> createDataConnection(const String& command);
	RefPtr<Socket> createPassiveDataConnection(const String& command);
	RefPtr<Socket> createActiveDataConnection(const String& command);
	void copyInputStream(InputStream* pFrom, OutputStream* pTo);
	void copyOutputStream(OutputStream* pFrom, InputStream* pTo);

private:
	String                 m_lastResponseMessage;
	int                    m_nResponseCode;
	DataConnectionType     m_dataConnectionType;
	TransferType           m_transferType;
	RefPtr<Writer>         m_rpControlWriter;
	RefPtr<BufferedReader> m_rpControlReader;
	size_t                 m_dataConnectionTimeout;
	bool                   m_bCheckInboundConnection;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_FtpClient_h
