//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:27 $
//
//==============================================================================
//
// Class: HttpChunkedInputStream
// 
// Overview
// --------
// This class is an ElCel Technology extension.
//
// A HttpChunkedInputStream is used to decode chunked results from a
// HTTP 1.1 GET request.
//
// See RFC 2616 (3.6.1) For a description of Chunked Encoding
// In a nut-shell, the result of an HTTP request is split into chunks, each
// chunk is prefixed by a chunk size field.  The last chunk has a size of "0".
//
//=============================================================================

#ifndef OT_NET_HttpChunkedInputStream_h
#define OT_NET_HttpChunkedInputStream_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "ot/io/FilterInputStream.h"

OT_NET_NAMESPACE_BEGIN

using io::FilterInputStream;

class OT_NET_PKG HttpChunkedInputStream : public FilterInputStream
{
public:
	HttpChunkedInputStream(InputStream* pInputStream);

#ifdef OT_USING_DECL_BROKEN
	virtual int read() {return FilterInputStream::read();}
#else
	using FilterInputStream::read; 	// unhide inherited read methods
#endif

	virtual long read(Byte* pBuffer, size_t bufLen);

protected:
	void readChunkHeader();

private:
	size_t m_chunkSize;
	size_t m_chunkRead;
	bool m_eof;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_HttpChunkedInputStream_h

