//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/03/16 22:51:59 $
//
//==============================================================================

#ifndef OT_NET_HttpClient_h
#define OT_NET_HttpClient_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "TcpNetworkClient.h"
#include "MimeHeaderSequence.h"
#include "URL.h"

#include "ot/io/Writer.h"

OT_NET_NAMESPACE_BEGIN

using io::Writer;

class OT_NET_PKG HttpClient : public virtual ManagedObject, private TcpNetworkClient
{
public:

	HttpClient();

	void connectToURL(const URL& url, size_t timeoutMS);

	void setProxyHost(const String& host);
	void setProxyPort(int port);

	String getProxyHost() const;
	int getProxyPort() const;

	String getRequestMethod() const;
	void setRequestMethod(const String& method);

	RefPtr<MimeHeaderSequence> getResponseHeaders() const;
	RefPtr<MimeHeaderSequence> getRequestHeaders() const;

	bool getFollowRedirects() const;
	void setFollowRedirects(bool bFollow);

	URL getURL() const;
	int sendRequest();

	int getResponseCode() const;
	const String& getResponseMessage() const;
	const String& getResponseLine() const;

	virtual RefPtr<InputStream> getInputStream() const;
	virtual RefPtr<OutputStream> getOutputStream() const;

protected:
	virtual int getDefaultPort() const;
	virtual void postConnect(const String& server, int port, size_t timeoutMS);

private:
	void parseReturnedHeaders();
	bool createAuthorizationHeader();

private:
	RefPtr<Writer>       m_rpWriter;
	RefPtr<InputStream>  m_rpInputStream;
	RefPtr<OutputStream> m_rpOutputStream;
	RefPtr<MimeHeaderSequence> m_rpRequestHeaders;
	RefPtr<MimeHeaderSequence> m_rpResponseHeaders;
	URL                  m_url;
	String               m_requestMethod;
	String               m_responseMessage;
	String               m_responseLine;
	int                  m_nResponseCode;
	bool                 m_bFollowRedirects;
	int                  m_nProxyPort;
	size_t               m_timeoutMS;
	String               m_proxyHost;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_HttpClient_h
