//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:29 $
//
//==============================================================================

#ifndef OT_NET_HttpURLConnection_h
#define OT_NET_HttpURLConnection_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "URLConnection.h"
#include "Socket.h"

OT_NET_NAMESPACE_BEGIN

class OT_NET_PKG HttpURLConnection : public URLConnection
{
public:

	enum HttpResponseCode {
		HTTP_ACCEPTED=202,
		HTTP_BAD_GATEWAY=502,
		HTTP_BAD_METHOD=405,
		HTTP_BAD_REQUEST=400,
		HTTP_CLIENT_TIMEOUT=408,
		HTTP_CONFLICT=409,
		HTTP_CREATED=201,
		HTTP_ENTITY_TOO_LARGE=413,
		HTTP_FORBIDDEN=403,
		HTTP_GATEWAY_TIMEOUT=504,
		HTTP_GONE=410,
		HTTP_INTERNAL_ERROR=500,
		HTTP_LENGTH_REQUIRED=411,
		HTTP_MOVED_PERM=301,
		HTTP_MOVED_TEMP=302,
		HTTP_MULT_CHOICE=300,
		HTTP_NO_CONTENT=204,
		HTTP_NOT_ACCEPTABLE=406,
		HTTP_NOT_AUTHORITATIVE=203,
		HTTP_NOT_FOUND=404,
		HTTP_NOT_IMPLEMENTED=501,
		HTTP_NOT_MODIFIED=304,
		HTTP_OK=200,
		HTTP_PARTIAL=206,
		HTTP_PAYMENT_REQUIRED=402,
		HTTP_PRECON_FAILED=412,
		HTTP_PROXY_AUTH=407,
		HTTP_REQ_TOO_LONG=414,
		HTTP_RESET=205,
		HTTP_SEE_OTHER=303,
		HTTP_UNAUTHORIZED=401,
		HTTP_UNAVAILABLE=503,
		HTTP_UNSUPPORTED_TYPE=415,
		HTTP_USE_PROXY=305,
		HTTP_VERSION=505 };

	HttpURLConnection(const URL& url);

	virtual void setRequestMethod(const String& method)=0;
	virtual String getRequestMethod() const=0;

	virtual int getResponseCode()=0;
	virtual String getResponseMessage()=0;

	virtual void setFollowRedirects(bool bFollow)=0;
	virtual bool getFollowRedirects() const=0;

	virtual RefPtr<InputStream> getErrorStream() const=0;

public: // public static methods
	static void SetDefaultFollowRedirects(bool bFollow);
	static bool GetDefaultFollowRedirects();

private: // static member variables
	static bool s_bDefaultFollowRedirects;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_HttpURLConnection_h
