//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.5 $
// $Date: 2003/09/10 20:44:46 $
//
//==============================================================================
//
// Class: InetAddress
// 
// Overview
// --------
// based on the java.net.InetAddress class.  Wraps an IP address and provides
// convenience functions for interogating the system's DNS query mechanism.
//
// Note: Currently we only wrap an IPv4 IP address but it should be 
// quite straight forward to enhance this for IPv6
//==============================================================================

#ifndef OT_NET_InetAddress_h
#define OT_NET_InetAddress_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

struct in_addr; // forward declaration

OT_NET_NAMESPACE_BEGIN

class OT_NET_PKG InetAddress : public virtual ManagedObject
{
public:
	~InetAddress();
	InetAddress(const InetAddress& rhs);
	InetAddress& operator=(const InetAddress& rhs);

	virtual String getHostAddress() const;
	virtual String getHostName() const;
	virtual String toString() const;

	virtual const Byte* getAddress() const;
	virtual size_t getAddressLength() const;

	virtual bool equals(const InetAddress& rhs) const;

	bool operator==(const InetAddress& rhs) const;
	bool operator!=(const InetAddress& rhs) const;

public: // Static functions

	static RefPtr<InetAddress> GetByName(const String& host);
	static RefPtr<InetAddress> GetLocalHost();
	static RefPtr<InetAddress> GetAnyHost();
	static RefPtr<InetAddress> GetLocalBroadcast();
	static RefPtr<InetAddress> FromNetworkAddress(const struct sockaddr* pAddr, size_t addrlen);

protected:
	InetAddress(); // default constructor protected, copying is okay though

private:
	struct in_addr* m_pAddr;
	mutable String m_hostName;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_InetAddress_h
