//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:30 $
//
//==============================================================================

#ifndef OT_NET_MimeHeaderSequence_h
#define OT_NET_MimeHeaderSequence_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include <utility>
#include <vector>

#include "ot/io/Writer.h"

OT_NET_NAMESPACE_BEGIN

using io::Writer;

class OT_NET_PKG MimeHeaderSequence : public virtual ManagedObject
{
	friend class MimeHeaderParser;

public:

	String getHeader(const String& key) const;
	String getHeader(size_t index) const;
	String getHeaderKey(size_t index) const;
	int findHeader(const String& key) const;
	bool containsHeader(const String& key) const;
	size_t size() const;
	void clear();

	void setHeaderExclusive(const String& key, const String& value);
	void insertHeader(const String& key, const String& value);
	bool setHeaderIfAbsent(const String& key, const String& value); 
	void removeAllHeaders(const String& key);

	void writeHeaders(Writer* pWriter);

private:
	typedef std::pair<String, String> HeaderFieldEntry;
	typedef std::vector<HeaderFieldEntry> HeaderFieldVector;
	HeaderFieldVector m_headerFields;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_MimeHeaderSequence_h
