//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1 $
// $Date: 2003/08/18 20:59:10 $
//
//==============================================================================
//
// Class: PlainDatagramSocketImpl
//
// Class PlainDatagramSocketImpl is a concrete implementation of the abstract class
// SocketImpl.  As its name implies, this class implements a plain vanilla
// socket as provided by the underlying operating system.
//
// Notes
// -----
// We hold members for the RefPtrs to the input/output streams.  This is 
// so that we may return the same stream whenever we are asked for it.
//
// The socket descriptor is held in a separate object to avoid a circular
// reference.
//==============================================================================

#ifndef OT_NET_PlainDatagramSocketImpl_h
#define OT_NET_PlainDatagramSocketImpl_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "DatagramSocketImpl.h"
#include "InetAddress.h"
#include "SocketDescriptor.h"

OT_NET_NAMESPACE_BEGIN

class OT_NET_PKG PlainDatagramSocketImpl : public DatagramSocketImpl
{
public:
	PlainDatagramSocketImpl();
	~PlainDatagramSocketImpl();

protected:
	virtual void bind(InetAddress* pAddress, int port);

	virtual void close();
	virtual void connect(InetAddress* pAddress, int port);
	virtual void create();
	virtual void disconnect();

	virtual RefPtr<InetAddress> getInetAddress() const;
	virtual RefPtr<InetAddress> getLocalAddress() const;

	virtual int getLocalPort() const;
	virtual int getPort() const;
	virtual RefPtr<SocketDescriptor> getSocketDescriptor() const;

	virtual String toString() const;

	virtual void send(const DatagramPacket& p);
	virtual void receive(DatagramPacket& p);

	// Socket Option methods
	virtual int getIntOption(int level, int option) const;
	virtual void getVoidOption(int level, int option, void* pOut, size_t* pLen) const;
	virtual void setIntOption(int level, int option, int value);
	virtual void setVoidOption(int level, int option, void* pValue, size_t valLen);
	virtual size_t getTimeout() const;
	virtual void setTimeout(size_t timeoutMS);

	virtual bool isClosed() const;
	virtual bool isConnected() const;
	virtual bool isBound() const;

private:
	void connectToAddress(InetAddress* pAddress, int port);
	void testSocketIsValid() const;

private:
	RefPtr<SocketDescriptor>   m_rpSocketDescriptor;
	mutable RefPtr<InetAddress>  m_rpLocalAddr;
	RefPtr<InetAddress>        m_rpRemoteAddr;
	int                        m_localPort;
	int                        m_remotePort;
	size_t                     m_nTimeoutMS;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_PlainDatagramSocketImpl_h
