//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.3 $
// $Date: 2003/09/04 21:10:53 $
//
//==============================================================================
//
// Class: PlainSocketImpl
//
// Class PlainSocketImpl is a concrete implementation of the abstract class
// SocketImpl.  As its name implies, this class implements a plain vanilla
// socket as provided by the underlying operating system.
//
// Notes
// -----
// We hold members for the RefPtrs to the input/output streams.  This is 
// so that we may return the same stream whenever we are asked for it.
//
// The socket descriptor is held in a separate object to avoid a circular
// reference.
//==============================================================================

#ifndef OT_NET_PlainSocketImpl_h
#define OT_NET_PlainSocketImpl_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "SocketImpl.h"
#include "InetAddress.h"
#include "SocketDescriptor.h"

OT_NET_NAMESPACE_BEGIN

class OT_NET_PKG PlainSocketImpl : public SocketImpl
{
public:
	PlainSocketImpl();
	~PlainSocketImpl();

protected:
	virtual void accept(SocketImpl* pSocket);
	virtual size_t available() const;
	virtual void bind(InetAddress* pAddress, int port);

	virtual void close();
	virtual void connect(InetAddress* pAddress, int port);
	virtual void connect(const String& host, int port);
	virtual void connect(InetAddress* pAddress, int port, size_t timeoutMS);
	virtual void create(bool bStream);

	virtual bool getAutoClose() const;
	virtual RefPtr<InetAddress> getInetAddress() const;
	virtual RefPtr<InetAddress> getLocalAddress() const;
	virtual RefPtr<InetAddress> getRemoteAddress() const;

	virtual RefPtr<InputStream> getInputStream() const;
	virtual int getLocalPort() const;
	virtual RefPtr<OutputStream> getOutputStream() const;
	virtual int getPort() const;
	virtual RefPtr<SocketDescriptor> getSocketDescriptor() const;

	virtual void listen(size_t backlog);
	virtual String toString() const;

	// Socket Option methods
	virtual int getIntOption(int level, int option) const;
	virtual void getVoidOption(int level, int option, void* pOut, size_t* pLen) const;
	virtual void setIntOption(int level, int option, int value);
	virtual void setVoidOption(int level, int option, void* pValue, size_t valLen);
	virtual size_t getTimeout() const;
	virtual void setTimeout(size_t timeoutMS);

	virtual void setAutoClose(bool bEnable);
	virtual void setSocketDescriptor(SocketDescriptor* pSocketDescriptor);
	virtual void setInetAddress(InetAddress* pAddress);
	virtual void setLocalPort(int localPort);
	virtual void setPort(int port);

	virtual void shutdownInput();
	virtual void shutdownOutput();
	virtual bool isClosed() const;
	virtual bool isConnected() const;
	virtual bool isBound() const;

private:
	void connectToAddress(InetAddress* pAddress, int port, size_t timeoutMS);
	void testSocketIsValid(bool bTestConnected) const;
	void setBlocking(bool bBlocking);

private:
	RefPtr<SocketDescriptor>   m_rpSocketDescriptor;
	mutable RefPtr<InputStream>  m_rpInputStream;
	mutable RefPtr<OutputStream> m_rpOutputStream;
	mutable RefPtr<InetAddress>  m_rpLocalAddr;
	RefPtr<InetAddress>        m_rpRemoteAddr;
	int                        m_localPort;
	int                        m_remotePort;
	bool                       m_bBlocking;
	bool                       m_bPassive;
	size_t                     m_nTimeoutMS;
	int                        m_sockType;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_PlainSocketImpl_h
