//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/08/10 22:16:35 $
//
//==============================================================================

#ifndef OT_NET_ServerSocket_h
#define OT_NET_ServerSocket_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

OT_NET_NAMESPACE_BEGIN

class InetAddress;
class Socket;
class SocketImpl;
class SocketImplFactory;

class OT_NET_PKG ServerSocket : public virtual ManagedObject 
{
public:

	ServerSocket();
	ServerSocket(int port);
	ServerSocket(int port, int backlog);
	ServerSocket(int port, int backlog, InetAddress* pBindAddr);

	virtual RefPtr<Socket> accept();
	virtual void bind(int port, int backlog, InetAddress* pBindAddr);
	virtual void bind(int port, int backlog);
	virtual void bind(int port);
	virtual void close();
	virtual RefPtr<InetAddress> getInetAddress() const;
	virtual int getLocalPort() const;
	virtual size_t getReceiveBufferSize() const;
	virtual bool getReuseAddress() const;
	virtual size_t getSoTimeout() const;
	virtual bool isBound() const;
	virtual void setReceiveBufferSize(size_t size);
	virtual void setReuseAddress(bool bEnable);
	virtual void setSoTimeout(size_t timeoutMS);
	virtual String toString() const;

public: // static functions 
	static void SetSocketImplFactory(SocketImplFactory* pFac);
	static RefPtr<SocketImplFactory> GetSocketImplFactory();

protected:
	void implAccept(Socket* pSocket);

private:
	void init();

private:
	RefPtr<SocketImpl> m_rpSocketImpl;
	bool m_bIsBound;

	static SocketImplFactory* OT_MT_VOLATILE s_pSocketImplFactory;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_Socket_h
