//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.4 $
// $Date: 2003/09/04 21:10:53 $
//
//==============================================================================
//
// Class: Socket
//
// This class should not need much introduction.  It provides a portable wrapper
// around BSD-Style sockets under Linux/Unix and WinSock sockets under Windows.
//
// Sockets provide a means of creating a data connection to another host.
//
//==============================================================================

#ifndef OT_NET_Socket_h
#define OT_NET_Socket_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "SocketImpl.h"

OT_NET_NAMESPACE_BEGIN

class InetAddress;
class SocketImplFactory;

class OT_NET_PKG Socket : public virtual ManagedObject 
{
	friend class ServerSocket;

	// Construction:

protected:
	// Creates an unconnected Socket with a user-specified SocketImpl. 
	Socket(SocketImpl* pImpl);

public:
	Socket();
	Socket(InetAddress* pAddress, int port);
	Socket(InetAddress* pAddress, int port, InetAddress* pLocalAddr, int localPort);
	Socket(const String& host, int port);
	Socket(const String& host, int port, InetAddress* pLocalAddr, int localPort);

	virtual void connect(InetAddress* pAddress, int port, size_t timeoutMS);
	virtual void connect(InetAddress* pAddress, int port);
	virtual void connect(const String& host, int port);
	virtual void close();
	virtual bool getAutoClose() const;
	virtual RefPtr<InetAddress> getInetAddress() const;
	virtual RefPtr<InputStream> getInputStream() const;
	virtual bool getKeepAlive() const;
	virtual RefPtr<InetAddress> getLocalAddress() const;
	virtual int getLocalPort() const;
	virtual RefPtr<OutputStream> getOutputStream() const;
	virtual int getPort() const;
	virtual int getReceiveBufferSize() const;
	virtual int getSendBufferSize() const;
	virtual int getSoLinger() const;
	virtual size_t getSoTimeout() const;
	virtual bool getTcpNoDelay() const;
	virtual bool isClosed();
	virtual bool isConnected();
	virtual void setAutoClose(bool bEnable);
	virtual void setKeepAlive(bool bEnable);
	virtual void setReceiveBufferSize(size_t size);
	virtual void setSendBufferSize(size_t size);
	virtual void setSoLinger(bool bEnable, size_t linger);
	virtual void setSoTimeout(size_t timeoutMS);
	virtual void setTcpNoDelay(bool bEnable);
	virtual void shutdownInput();
	virtual void shutdownOutput();
	virtual String toString() const;

public: // static methods
	static void SetSocketImplFactory(SocketImplFactory* pFac);
	static RefPtr<SocketImplFactory> GetSocketImplFactory();

private:
	void createSocketImpl();
	RefPtr<SocketImpl> getSocketImpl() const;

private:
	RefPtr<SocketImpl> m_rpSocketImpl;

	static SocketImplFactory* OT_MT_VOLATILE s_pSocketImplFactory;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_Socket_h
