//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.4 $
// $Date: 2003/09/04 21:10:53 $
//
//==============================================================================
//
// Class: SocketDescriptor
//
// A reference-counted object containing an OS Socket Descriptor.
//
// The purpose of this class is to mirror the action an OS takes in
// reference-counting file descriptors - but without the downside
// of using a scarse OS resource.
//
// When the SocketDescriptor reference count goes to zero, and this
// class is destroyed, the contained OS socket descriptor is closed.
//==============================================================================

#ifndef OT_NET_SocketDescriptor_h
#define OT_NET_SocketDescriptor_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "ot/base/SynchronizedObject.h"
#include "ot/io/ResourceDescriptor.h"

OT_NET_NAMESPACE_BEGIN

using io::ResourceDescriptor;

class OT_NET_PKG SocketDescriptor : public ResourceDescriptor, public SynchronizedObject
{
public:
	typedef OT_SOCKET_FD OSSocketDescriptorType;

	enum Flags {ShutdownInput=1,
	            ShutdownOutput=2,
				HasOutputStream=4,
				DescriptorClosed=8,
				AutoCloseEnabled=16};

	SocketDescriptor(OSSocketDescriptorType fd);
	~SocketDescriptor();

	void close();
	virtual String toString() const;
	OSSocketDescriptorType getFD() const;

	int getSocketFlags() const;
	void setSocketFlags(int flags);
	int modifySocketFlags(int flagsToSet, int flagsToUnset);

private:
	OSSocketDescriptorType m_fd;
	int                    m_flags;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_SocketDescriptor_h
