//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:36 $
//
//==============================================================================

#ifndef OT_NET_TcpNetworkClient_h
#define OT_NET_TcpNetworkClient_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "Socket.h"
#include "InetAddress.h"

OT_NET_NAMESPACE_BEGIN

class OT_NET_PKG TcpNetworkClient : public virtual ManagedObject
{
public:

	virtual void connect(const String& host, int port=-1, size_t timeoutMS=0);
	virtual void disconnect();
	virtual bool isConnected() const;
	virtual RefPtr<InetAddress> getServerAddress() const;
	virtual RefPtr<InetAddress> getLocalAddress() const;
	virtual RefPtr<InputStream> getInputStream() const;
	virtual RefPtr<OutputStream> getOutputStream() const;
	virtual int getServerPort() const;

protected:

	virtual int getDefaultPort() const=0;
	virtual void postConnect(const String& server, int port, size_t timeoutMS);
	virtual void preDisconnect();
	virtual RefPtr<Socket> createConnection(const String& host, int port, size_t timeoutMS);
	
private:
	RefPtr<Socket> m_rpSocket;
	RefPtr<InputStream> m_rpInputStream;
	RefPtr<OutputStream> m_rpOutputStream;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_TcpNetworkClient_h
