//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:37 $
//
//==============================================================================

#ifndef OT_NET_URL_h
#define OT_NET_URL_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "URLStreamHandler.h" // reqd for RefPtr<>

#include "ot/base/RefPtr.h"

OT_NET_NAMESPACE_BEGIN

class URLConnection;

class OT_NET_PKG URL
{
public:

	friend class URLStreamHandler;

	URL();
	URL(const String& spec);
	URL(const URL& context, const String& spec);
	URL(const String& protocol, const String& host, int port, const String& file);
	URL(const String& protocol, const String& host, int port, const String& file, URLStreamHandler* pHandler);
	URL(const String& protocol, const String& host, const String& file);

	const String& getAuthority() const;
	String getFile() const;
	const String& getHost() const;
	const String& getPath() const;
	int getPort() const;
	const String& getProtocol() const;
	const String& getQuery() const;
	const String& getRef() const;
	const String& getUserInfo() const;

	String getPassword() const;
	String getUserID() const;

	bool sameFile(const URL& rhs) const;
	String toExternalForm() const;

	bool equals(const URL& rhs) const;
	bool operator==(const URL& rhs) const;
	bool operator!=(const URL& rhs) const;

	RefPtr<URLConnection> openConnection() const;
	RefPtr<InputStream> openStream() const;
	RefPtr<URLStreamHandler> getStreamHandler() const;

private:
	void parseSpecification(const String& spec);

	void set(const String& protocol,
             const String& host,
             int port,
             const String& authority,
             const String& userInfo,
             const String& path,
             const String& query,
             const String& ref);

	void init(const String& protocol,
	          const String& host,
	          int port,
	          const String& file,
	          URLStreamHandler* pHandler);

private:
	String m_protocol;
	String m_authority;
	String m_host;
	String m_path;
	String m_query;
	String m_ref;
	String m_userInfo;
	int m_port;
	RefPtr<URLStreamHandler> m_rpHandler;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_URL_h

