//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/03/15 21:41:19 $
//
//==============================================================================

#ifndef OT_NET_URLConnection_h
#define OT_NET_URLConnection_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

#include "URL.h"
#include "ot/util/DateTime.h"
#include <vector>

OT_NET_NAMESPACE_BEGIN

using util::DateTime;

class OT_NET_PKG URLConnection : public virtual ManagedObject
{
public:
	URLConnection(const URL& url);

	virtual void connect() = 0;

	virtual String getContentEncoding();
	virtual long getContentLength();
	virtual String getContentType();
	virtual DateTime getDate();
	virtual DateTime getLastModified();
	
	virtual RefPtr<InputStream> getInputStream() = 0;
	virtual RefPtr<OutputStream> getOutputStream() = 0;

	virtual String getHeaderField(const String& name) = 0;
	virtual String getHeaderField(size_t index) = 0;
	virtual String getHeaderFieldKey(size_t index) = 0;
	virtual size_t getHeaderFieldCount() = 0;
	
	virtual void setRequestProperty(const String& name, const String& value);
	virtual String getRequestProperty(const String& name) const;

	virtual DateTime getHeaderFieldDate(const String& name);
	virtual long getHeaderFieldLong(const String& name, long defaultValue);
	virtual const URL& getURL() const;

	void setUseCaches(bool bUseCaches);
	bool getUseCaches() const;

	bool getDoInput() const;
	void setDoInput(bool bEnable);
	bool getDoOutput() const;
	void setDoOutput(bool bEnable);

	bool isConnected() const;

	static void SetDefaultUseCaches(bool bUseCaches);
	static bool GetDefaultUseCaches();

protected:
	void setConnected(bool bConnected);
	void resetHeaderFields();
	void setURL(const URL& url);

private:
	bool m_bConnected;
	std::vector<std::pair<String, String> > m_headerFields;
	URL m_url;
	bool m_bUseCaches;
	enum TriState {TriUnspecified, TriTrue, TriFalse};
	TriState m_doInput;
	TriState m_doOutput;

private: // static members
	static bool s_bUseCachesDefault;
};

OT_NET_NAMESPACE_END

#endif //OT_NET_URLConnection_h

