//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:39 $
//
//==============================================================================
//
// Class: URLEncoder
// 
// Overview
// --------
// based on the java.net.URLEncoder class.  Provides the capability to encode
// a unicode URL into its www escaped form
//
// see http://java.sun.com/products/jdk/1.0.2/api/java.net.URLEncoder.html
// for documentation.
//
// Note: the JDK URLEncoder has a deficiency that this class does NOT copy,
// that is the inability to deal with non ASCII characters.
//
// Also, the function name is changed from encode to Encode to satisfy the
// ElCel static function naming convention.
//=============================================================================

#ifndef OT_NET_URLEncoder_h
#define OT_NET_URLEncoder_h

#ifndef OT_NET_defs_h
#include "defs.h"
#endif //OT_NET_defs_h

OT_NET_NAMESPACE_BEGIN

class OT_NET_PKG URLEncoder
{
public:
	// Translates a string into x-www-form-urlencoded format.
	static String Encode(const String& s);
	
	// Encode the uri string using the up-to-date algorithm
	static String RawEncode(const String& s);
};

OT_NET_NAMESPACE_END

#endif //OT_NET_URLEncoder_h

