//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.7 $
// $Date: 2003/09/10 20:57:14 $
//
//==============================================================================
/**
	@namespace ot::net

	Extends the I/O capabilities of @OpenTop to include network access.  Includes
	classes for accessing World Wide Web resources via URLs as well as
	stream-oriented (TCP) and connectionless (UDP) sockets.
*/
//==============================================================================

#ifndef OT_NET_defs_h
#define OT_NET_defs_h

#include "ot/base/gendefs.h"
#include "ot/base/ManagedObject.h"
#include "ot/base/RefPtr.h"
#include "ot/base/String.h"
#include "ot/io/InputStream.h"
#include "ot/io/OutputStream.h"

#ifdef WIN32
	#define OT_SOCKET_FD            unsigned int
	#define OT_INVALID_SOCKET       INVALID_SOCKET
#else
	#define OT_SOCKET_FD            int
	#define OT_INVALID_SOCKET       -1
#endif

#if defined (OT_IOS_EXPORT)
	//
	// Windows sockets uses different symbols for error numbers and
	// other flags.  To avoid conditional compilation in the code,
	// we define them here to be the same as the Unix codes
	//
	#ifdef WIN32

		#include <winsock2.h>
		#define SHUT_RD                 SD_RECEIVE
		#define SHUT_WR                 SD_SEND
		#define SHUT_RDWR               SD_BOTH
		#define HOST_NOT_FOUND          WSAHOST_NOT_FOUND
		#define EWOULDBLOCK             WSAEWOULDBLOCK
		#define EINPROGRESS             WSAEWOULDBLOCK
		#define EISCONN                 WSAEISCONN
		#define ECONNABORTED            WSAECONNABORTED
		#define ECONNRESET              WSAECONNRESET
		#define ETIMEDOUT               WSAETIMEDOUT
		#define ENETUNREACH             WSAENETUNREACH
		#define EHOSTUNREACH            WSAEHOSTUNREACH
		#define EMSGSIZE                WSAEMSGSIZE
		#define EPROTO                  0 // not present on WIN32

	#else // !WIN32

		#include <errno.h>              // reqd for testing presence of EXXXX defines
		#include <netinet/in.h>         // reqd for FreeBSD
		#include <arpa/inet.h>
		extern "C" {                    // reqd for HP-UX
			#include <netdb.h>
		}
		#include <sys/socket.h>         // reqd for SHUT_RD etc

	#endif //WIN32

	//
	// Not all platforms define the following symbolic constants
	//
	#ifndef SHUT_RD
		#define SHUT_RD 0
	#endif //SHUT_RD

	#ifndef SHUT_WR
		#define SHUT_WR 1
	#endif //SHUT_WR

	#ifndef SHUT_RDWR
		#define SHUT_RDWR 2
	#endif //SHUT_WR

	// Some systems don't have INADDR_NONE defined...
	#ifndef INADDR_NONE
		#define INADDR_NONE 0xffffffff
	#endif

	// Some systems (win32) don't have MAXHOSTNAMELEN defined...
	#ifndef MAXHOSTNAMELEN
		#define MAXHOSTNAMELEN 255
	#endif

	// FreeBSD does not define EPROTO
	#ifndef EPROTO
		#define EPROTO EPROTONOSUPPORT // BSD has no eproto
	#endif

	#ifdef HAVE_WORKING_SOCKLEN_T
		typedef socklen_t cel_socklen_t;
	#else
		typedef int cel_socklen_t;
	#endif

#endif //OT_IOS_EXPORT


#define OT_NET_PKG OT_OPENTOP_PKG
#define OT_NET_INCLUDE_INLINES OT_OPENTOP_INCLUDE_INLINES
#define OT_NET_NAMESPACE_BEGIN OT_SUB_NAMESPACE_BEGIN(net)
#define OT_NET_NAMESPACE_END   OT_SUB_NAMESPACE_END(net)

//
// Under MSVC, automatically link to required library
//
#if defined(_MSC_VER) && (defined(OT_IOS_EXPORT) || !defined(OT_DLL))
	#pragma comment(lib, "ws2_32.lib")
#endif

OT_NET_NAMESPACE_BEGIN

using io::InputStream;
using io::OutputStream;

OT_NET_NAMESPACE_END

#endif //OT_NET_defs_h
