//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:42 $
//
//==============================================================================

#ifndef OT_SAX_DefaultHandler_h
#define OT_SAX_DefaultHandler_h

#include "ContentHandler.h"
#include "DTDHandler.h"
#include "EntityResolver.h"
#include "ErrorHandler.h"

OT_SAX_NAMESPACE_BEGIN

class OT_SAX_PKG DefaultHandler : public ContentHandler,
                                   public DTDHandler,
                                   public EntityResolver,
                                   public ErrorHandler
{
public:

	// ContentHandler methods...
	virtual void characters(const CharType* pStart, size_t length);
	virtual void endElement(const String& namespaceURI,
	                        const String& localName,
	                        const String& qName);
	virtual void endPrefixMapping(const String& prefix);
	virtual void ignorableWhitespace(const CharType* pStart, size_t length);
	virtual void processingInstruction(const String& target, const String& data);
	virtual void startElement(const String& namespaceURI,
	                          const String& localName,
	                          const String& qName,
	                          const Attributes& atts);
	virtual void startPrefixMapping(const String& prefix, const String& uri);
	virtual void startDocument();
	virtual void skippedEntity(const String& name);
	virtual void endDocument();
	virtual void setDocumentLocator(Locator* pLocator);

	// DTDHandler methods...
	virtual void notationDecl(const String& name, const String& publicId, const String& systemId);
	virtual void unparsedEntityDecl(const String& name, const String& publicId, const String& systemId, const String& notationName);


	// ErrorHandler methods...
	virtual void error(const SAXParseException& exception);
	virtual void fatalError(const SAXParseException& exception);
	virtual void warning(const SAXParseException& exception);
	
	// EntityResolver methods...
	virtual RefPtr<InputSource> resolveEntity(const String& publicId,
	                                          const String& systemId);
};

OT_SAX_NAMESPACE_END

#endif // OT_SAX_DefaultHandler_h
