//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:45 $
//
//==============================================================================

#ifndef OT_SAX_NamespaceSupport_h
#define OT_SAX_NamespaceSupport_h

#include "defs.h"

#include <list>
#include <deque> // reqd for gcc 2.96
#include <map>
#include <stack>

OT_SAX_NAMESPACE_BEGIN 

class OT_SAX_PKG NamespaceSupport : public ManagedObject
{
public:

	NamespaceSupport();

	typedef std::list<String> PrefixList;
 
	bool declarePrefix(const String& prefix, const String& uri);
	PrefixList getDeclaredPrefixes() const;
	String getPrefix(const String& uri) const;
	PrefixList getPrefixes() const;
	PrefixList getPrefixes(const String& uri) const;
	String getURI(const String& prefix) const;
	void popContext();
	bool processName(const String& qName, bool bAttribute,
	                 String& retUri, String& retLocal) const;
	void pushContext();
	void reset();

	static const String XMLNS;

private:

	void init();

private:

	struct NamespaceContext
	{
		typedef std::map<String, String, std::less<String> > PrefixMap;

		String m_defaultURI;
		PrefixMap m_prefixMap;
		PrefixList m_deltaPrefixList;
	};

	typedef std::stack<NamespaceContext, std::deque<NamespaceContext> > NamespaceContextStack;
	NamespaceContextStack m_namespaceContextStack;
};

OT_SAX_NAMESPACE_END

#endif //OT_SAX_NamespaceSupport_h
