//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:45 $
//
//==============================================================================
// Class: SAXException
// 
/**
	@class ot::sax::SAXException
	
	@brief Encapsulate a general SAX error or warning.
	       
	<p>This class can contain basic error or warning information from
	either the XML parser or the application: a parser writer or
	application writer can subclass it to provide additional
	functionality.  SAX handlers may throw this exception or
	any exception @a derived from it.</p>
	
	<p>If the parser or application needs to include information about a
	specific location in an XML document, it should use the
	SAXParseException @a derived class.</p>
*/
//==============================================================================

#ifndef OT_SAX_SAXException_h
#define OT_SAX_SAXException_h

#ifndef OT_SAX_defs_h
#include "defs.h"
#endif //OT_SAX_defs_h

#include "ot/base/Exception.h"

OT_SAX_NAMESPACE_BEGIN

class OT_SAX_PKG SAXException : public Exception
{
public:
	/** Constructs a SAXException with a detail message
	* @param message the detail message.
	*/
	SAXException(const String& message) : 
		Exception(message)
	{}
	
	virtual String getExceptionType() const {return OT_T("SAXException");}
};


OT_SAX_NAMESPACE_END

#endif //OT_SAX_SAXException_h

