//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:47 $
//
//==============================================================================
// Class: SAXParser
// 
// Overview
// --------
// Implementation of XMLReader using the ElCel XML Parser.
//
//=============================================================================

#ifndef OT_SAX_SAXParser_h
#define OT_SAX_SAXParser_h

#include "defs.h"
#include "XMLReader.h"
#include "ContentHandler.h"
#include "DTDHandler.h"
#include "EntityResolver.h"
#include "LexicalHandler.h"
#include "LocatorAdaptor.h"

#include "ot/base/AutoBuffer.h"
#include "ot/xml/Parser.h"
#include "ot/xml/ContentEventHandler.h"
#include "ot/xml/DTDEventHandler.h"
#include "ot/xml/EntityEventHandler.h"
#include "ot/xml/EntityResolutionHandler.h"
#include "ot/xml/ErrorEventHandler.h"

OT_SAX_NAMESPACE_BEGIN

using xml::Parser;
using xml::ContentEventHandler;
using xml::DTDEventHandler;
using xml::EntityEventHandler;
using xml::EntityResolutionHandler;
using xml::ErrorEventHandler;
using xml::Position;
using xml::ContextString;
using xml::BufferRange;
using xml::EntityType;
using xml::QName;
using xml::AttributeSet;

class OT_SAX_PKG SAXParser : public XMLReader,
                              public ContentEventHandler,
                              public DTDEventHandler,
                              public ErrorEventHandler,
                              public EntityEventHandler,
                              public EntityResolutionHandler
{
public: 
	SAXParser();

public: // sax::XMLReader overrides...
	virtual void parse(const String& systemId);
	virtual void parse(InputSource* pInputSource);

	virtual RefPtr<ContentHandler> getContentHandler() const;
	virtual RefPtr<DeclHandler> getDeclHandler() const;
	virtual RefPtr<DTDHandler> getDTDHandler() const;
	virtual RefPtr<EntityResolver> getEntityResolver() const;
	virtual RefPtr<ErrorHandler> getErrorHandler() const;
	virtual RefPtr<LexicalHandler> getLexicalHandler() const;
	virtual bool getFeature(const String& name) const;

	virtual void setContentHandler(ContentHandler* pHandler);
	virtual void setDeclHandler(DeclHandler* pHandler);
	virtual void setDTDHandler(DTDHandler* pHandler);
	virtual void setEntityResolver(EntityResolver* pResolver);
	virtual void setErrorHandler(ErrorHandler* pHandler);
	virtual void setLexicalHandler(LexicalHandler* pHandler);
	virtual void setFeature(const String& name, bool bSet);

protected: 

	// ContentEventHandler methods
	virtual void onComment(const CharType* pComment, size_t length);
	virtual void onCommentStart(bool bInsideDTD);
	virtual void onCommentEnd(bool bInsideDTD);
	virtual void onPI(const String& PITarget, const String& PIValue);
	virtual void onStartElement(const QName& elementName, bool bEmptyElement, const AttributeSet& attributes);
	virtual void onEndElement(const QName& elementName);
	virtual void onWhitespace(const CharType* pChars, size_t length);
	virtual void onIgnorableWhitespace(const CharType* pChars, size_t length);
	virtual void onCharData(const CharType* pChars, size_t length);
	virtual void onNamespaceBegin(const String& prefix, const String& uri);
	virtual void onNamespaceChange(const String& prefix, const String& uriFrom, const String& uriTo, bool bRestoring);
	virtual void onNamespaceEnd(const String& prefix, const String& uri);
	virtual void onStartCData();
	virtual void onEndCData();
	virtual void onStartDocument(const String& systemId);
	virtual void onEndDocument();
	virtual void onXMLDeclaration(const String& version, const String& encoding, bool bStandalone);

	// ErrorEventHandler methods
	virtual void onError(int level, long reserved, const String& error, const Position& position, const ContextString* pContext);

	// DTDEventHandler methods
	virtual void onStartDTD(const String& name, const String& publicId, const String& systemId);
	virtual void onEndDTD();
	virtual void onNotationDecl(const String& name, const String& publicId, const String& systemId);
	virtual void onUnparsedEntityDecl(const String& name, const String& publicId, const String& systemId, const String& notationName);
	virtual void onExternalEntityDecl(const String& name, EntityType type, const String& publicId, const String& systemId);
	virtual void onInternalEntityDecl(const String& name, EntityType type, const String& value);
	virtual void onStartAttlist(const String& eName);
	virtual void onEndAttlist();
	virtual void onAttributeDecl(const String& eName, const String& aName, const String& type, const String& valueDefault, const String& enumGroup, const String& value);
	virtual void onElementDecl(const String& name, const String& model);

	// EntityResolver methods
	virtual RefPtr<XMLInputSource> onResolveEntity(const String& name,
	                                               EntityType type,
	                                               const String& publicId,
	                                               const String& systemId,
	                                               const String& baseUri);
	
	// EntityEventHandler methods
	virtual void onUnexpandedEntity(const String& name,
	                                EntityType type,
	                                const String& publicId,
	                                const String& systemId,
	                                const String& baseUri);

	virtual void onStartEntity(const String& name,
	                           EntityType type);

	virtual void onEndEntity(const String& name,
	                         EntityType type);

private:
	String resolveSystemId(const String& id, bool bDTDDecl) const;

private:
	RefPtr<ContentHandler> m_rpContentHandler;
	RefPtr<DeclHandler> m_rpDeclHandler;
	RefPtr<DTDHandler> m_rpDTDHandler;
	RefPtr<EntityResolver> m_rpEntityResolver;
	RefPtr<ErrorHandler> m_rpErrorHandler;
	RefPtr<LexicalHandler> m_rpLexicalHandler;
	RefPtr<Parser> m_rpParser;
	RefPtr<LocatorAdaptor> m_rpLocator;
	AutoBuffer<CharType> m_commentBuffer;
	bool m_bResolveDTDURIs;
	bool m_bResolveEntityURIs;
};

OT_SAX_NAMESPACE_END

#endif //OT_SAX_SAXParser_h

