//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:47 $
//
//==============================================================================

#ifndef OT_SAX_XMLReader_h
#define OT_SAX_XMLReader_h

#include "defs.h"

#include "ContentHandler.h"
#include "EntityResolver.h"
#include "DTDHandler.h"
#include "ErrorHandler.h"
#include "LexicalHandler.h"
#include "DeclHandler.h"

OT_SAX_NAMESPACE_BEGIN 

class OT_SAX_PKG XMLReader : public virtual ManagedObject
{
public:
	virtual RefPtr<ContentHandler> getContentHandler() const = 0;
	virtual RefPtr<DeclHandler> getDeclHandler() const = 0;
	virtual RefPtr<DTDHandler> getDTDHandler() const = 0;
	virtual RefPtr<EntityResolver> getEntityResolver() const = 0;
	virtual RefPtr<ErrorHandler> getErrorHandler() const = 0;
	virtual RefPtr<LexicalHandler> getLexicalHandler() const = 0;

	virtual bool getFeature(const String& name) const = 0;
          
	virtual void parse(InputSource* pInputSource) = 0;
	virtual void parse(const String& systemId) = 0;
          
	virtual void setContentHandler(ContentHandler* pHandler) = 0;
	virtual void setDeclHandler(DeclHandler* pHandler) = 0;
	virtual void setDTDHandler(DTDHandler* pHandler) = 0;
	virtual void setEntityResolver(EntityResolver* pResolver) = 0;
	virtual void setErrorHandler(ErrorHandler* pHandler) = 0;
	virtual void setLexicalHandler(LexicalHandler* pHandler) = 0;
	virtual void setFeature(const String& name, bool bSet) = 0;
};

OT_SAX_NAMESPACE_END

#endif //OT_SAX_XMLReader_h
