//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:48 $
//
//==============================================================================
/**
	@namespace ot::sax

	Provides a standardized SAX 2.0 interface to the @OpenTop XML parser.

    <p><b>SAX</b> is an acronym standing for "Simple API for XML".  It was originally 
	a Java API and has become the "de facto" standard for parsing XML using Java.</p>

    <p>There is not a recognized standard C++ representation for SAX.  However,
    the @OpenTop SAX implementation is able to follow the Java API very closely
	by using the @OpenTop framework facilities for Unicode, networking, IO
	and object lifetime management.</p>

    <p>Further details about SAX may be obtained from the SAX project
	home page: <a href="http://www.saxproject.org/">www.saxproject.org</a>.</p>
*/
//==============================================================================

#ifndef OT_SAX_defs_h
#define OT_SAX_defs_h

#include "ot/base/gendefs.h"
#include "ot/base/ManagedObject.h"
#include "ot/base/RefPtr.h"
#include "ot/base/String.h"
#include "ot/io/InputStream.h"
#include "ot/io/Reader.h"

#include "ot/xml/defs.h"

#define OT_SAX_PKG OT_OTXML_PKG
#define OT_SAX_INCLUDE_INLINES OT_OTXML_INCLUDE_INLINES
#define OT_SAX_NAMESPACE_BEGIN OT_SUB_NAMESPACE_BEGIN(sax)
#define OT_SAX_NAMESPACE_END   OT_SUB_NAMESPACE_END(sax)

//
// import types into sax namespace
//
OT_SAX_NAMESPACE_BEGIN

using io::InputStream;
using io::Reader;

OT_SAX_NAMESPACE_END

#endif //OT_SAX_defs_h
