//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:50 $
//
//==============================================================================
//
// Class MessageFormatter
//
// MessageFormatter is a replacement for sprintf that enables messages to be
// created using positional replacement.
//
// A typical use would be:
//
// cout << MessageFormatter::Format("Illegal value {0} expecting {1}",
//                                  sValue, sExpected);
//
// The Format() method is overloaded to allow type-safe checking of the
// input parameters (which are always String&s).
//==============================================================================
#ifndef OT_UTIL_MessageFormatter_h
#define OT_UTIL_MessageFormatter_h

#ifndef OT_UTIL_defs_h
#include "defs.h"
#endif //OT_UTIL_defs_h

OT_UTIL_NAMESPACE_BEGIN

class OT_UTIL_PKG MessageFormatter
{
public:
	
	static String Format(const String& spec, const String& arg1);
	static String Format(const String& spec, const String& arg1, const String& arg2);
	static String Format(const String& spec, const String& arg1, const String& arg2, const String& arg3);
	static String Format(const String& spec, const String& arg1, const String& arg2, const String& arg3, const String& arg4);
	static String Format(const String& spec, const String& arg1, const String& arg2, const String& arg3, const String& arg4, const String& arg5);
	static String Format(const String& spec, const String& arg1, const String& arg2, const String& arg3, const String& arg4, const String& arg5, const String& arg6);

protected:
	static String FormatImpl(const String& spec, size_t count, ...);

private:
	MessageFormatter(); // not implemented
};

OT_UTIL_NAMESPACE_END

#endif //OT_UTIL_MessageFormatter_h

