//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:51 $
//
//==============================================================================
//
// Class: ValueRestorer
//
// This is a simple class that takes a copy of a variable and restores its
// value on destruction.
//
//==============================================================================

#ifndef OT_UTIL_ValueRestorer_h
#define OT_UTIL_ValueRestorer_h

#ifndef OT_UTIL_defs_h
#include "defs.h"
#endif //OT_UTIL_defs_h

OT_UTIL_NAMESPACE_BEGIN

template <typename T>
class ValueRestorer
{
public:

	ValueRestorer(T& ref) :
		m_ref(ref),
		m_oldVal(ref),
		m_bRestoreOnDestruct(true)
	{
	}

	ValueRestorer(T& ref, const T& newVal) :
		m_ref(ref),
		m_oldVal(ref),
		m_bRestoreOnDestruct(true)
	{
		ref = newVal;
	}

	~ValueRestorer()
	{
		if(m_bRestoreOnDestruct)
			m_ref = m_oldVal;
	}

	void release()
	{
		m_bRestoreOnDestruct = false;
	}

private:
	T& m_ref;
	const T m_oldVal;
	bool m_bRestoreOnDestruct;
};

OT_UTIL_NAMESPACE_END

#endif //OT_UTIL_ValueRestorer_h

