//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:51 $
//
//==============================================================================
//
// Class: Attribute
// 
// Overview
// --------
// A class to encapsulate and store information about an attribute from an
// element start tag.
//
//==============================================================================

#ifndef OT_XML_Attribute_h
#define OT_XML_Attribute_h

#include "defs.h"
#include "QName.h"

OT_XML_NAMESPACE_BEGIN

class OT_XML_PKG Attribute : public virtual ManagedObject
{
	friend class ParserImpl;

public:

	// Create a parsed attribute
	Attribute(const QName& name,
			  const String& type,
			  int nIndex);

	// Create a "defaulted" attribute
	Attribute(const QName& name,
	          const String& value,
			  const String& type);

	// Default constructor - should never be used but std::map may require it's definition
	Attribute();

	Attribute(const Attribute& rhs);

	int getIndex() const;
	const QName& getName() const;
	const String& getValue() const;
	bool isDefaulted() const;
	const String& getType() const;

	void setName(const QName& name);
	void setValue(const String& value);
	void setType(const String& type);

private:
	QName m_name;
	String m_value;
	String m_type;
	int m_nIndex;
};

OT_XML_NAMESPACE_END

#endif //OT_XML_Attribute_h

