//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:51 $
//
//==============================================================================
//
// Class: AttributeSet
// 
// Overview
// --------
// A virtual base (interface) class to encapsulate and provide convenient
// access to the set of Attributes from an element start tag.
//
// Note: We elected to expose the Attribute Class rather than returning
// String values for two reasons:
// 1) Implementations may want to create their own Attribute derivative
// 2) It allows us to retun null when no matching attribute exists.
//
//
// Implementations of this interface have a difficult size/speed trade-off
// to make.  The SAX interface requires direct access to an attribute
// via an index, indicating the use of a std::vector.  However, it also 
// requires direct access via a name, or a name/uri pair indicating use of
// a map.
//
// Some applications also expect attributes to be sorted, and well-formedness
// requires that attributes are unique.
//
// For all these reasons the collection of attributes has been encapsulated
// behind this general-purpose interface.
//
//==============================================================================

#ifndef OT_XML_AttributeSet_h
#define OT_XML_AttributeSet_h

#include "Attribute.h"

OT_XML_NAMESPACE_BEGIN

class OT_XML_PKG AttributeSet
{
public:
	virtual ~AttributeSet() {};

	virtual RefPtr<Attribute> getAttribute(const String& uri, const String& localName) const = 0;
	virtual RefPtr<Attribute> getAttribute(const String& qName) const = 0;
	virtual RefPtr<Attribute> getAttribute(size_t index) const = 0;
	virtual bool addAttribute(Attribute* pAttribute) = 0;
	virtual void removeAttribute(size_t index) = 0;
	virtual void removeAll() = 0;
	
	virtual bool empty() const = 0;
	virtual size_t size() const = 0;
};

OT_XML_NAMESPACE_END

#endif //OT_XML_AttributeSet_h

