//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:52 $
//
//==============================================================================
//
// Class: AttributeType
// 
// Overview
// --------
// Records information about an element type's attribute definition (from a DTD)
//
//==============================================================================

#ifndef OT_XML_AttributeType_h
#define OT_XML_AttributeType_h

#ifndef OT_XML_defs_h
#include "defs.h"
#endif //OT_XML_defs_h

#include "DTDObject.h"
#include "QName.h"

#include <set>

OT_XML_NAMESPACE_BEGIN

class Attribute;
class ParserImpl;
class ElementType;

class OT_XML_PKG AttributeType : public DTDObject
{
public:

	enum Type {UNKNOWN, CDATA, ID, IDREF, IDREFS, ENTITY, ENTITIES, NMTOKEN,
	           NMTOKENS, NOTATION, ENUMERATION};

	enum DefaultType {REQUIRED, IMPLIED, DEFAULT, FIXED};

	AttributeType(ElementType& elementType, bool bExternallyDeclared, const QName& name);
	~AttributeType();

	DefaultType getDefaultType() const;
	Type getType() const;
	String getTypeAsString() const;
	String getEnumListAsString() const;
	const String& getDefaultValue() const;
	const QName& getName() const;

	void setDefaultType(DefaultType eDefaultType);
	void setType(Type eType);
	void setDefaultValue(const String& value, ParserImpl& parser);

	bool addEnum(const String& name, ParserImpl& parser);
	bool containsEnum(const String& name) const;
	bool hasDefaultValue() const;

	void validate(ParserImpl& parser) const;
	void validateAttribute(const Attribute& attr, ParserImpl& parser) const;
	bool isEnumerated() const;
	bool isStringType() const;
	bool isTokenized() const;

	static String GetTypeAsString(Type eType);

private:
	bool testNmToken(bool bDefault, bool bName, const String& value, ParserImpl& parser) const;
	bool testNmTokens(bool bDefault, bool bName, const String& value, ParserImpl& parser) const;
	bool testEntity(const String& value, ParserImpl& parser) const;

private: // not implemented
	AttributeType(const AttributeType& rhs);            // cannot be copied
	AttributeType& operator=(const AttributeType& rhs); // nor assigned

private:
	String m_defaultValue;
	typedef std::set<String, std::less<String> > EnumSet;
	EnumSet m_enums;
	DefaultType m_eDefaultType;
	ElementType& m_elementType;
	Type m_eType;
	QName m_name;
};

OT_XML_NAMESPACE_END

#endif //OT_XML_AttributeType_h
