//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:54 $
//
//==============================================================================

#ifndef OT_XML_ElementContentSpec_h
#define OT_XML_ElementContentSpec_h

#ifndef OT_XML_defs_h
#include "defs.h"
#endif //OT_XML_defs_h

#include <vector>
#include <map>

OT_XML_NAMESPACE_BEGIN

class ParserImpl;

class OT_XML_PKG ElementContentSpec
{
public:

	typedef std::vector<ElementContentSpec*> Children;
	typedef std::map<String, const ElementContentSpec*, std::less<String> > Map;
	
	enum ListType {Seq, Choice, Terminal};
	enum Multiplicity {One, Optional, ZeroOrMore, OneOrMore};

	// creates a top-level parent
	ElementContentSpec(const String& name); 
	
	// creates a terminal
	ElementContentSpec(ElementContentSpec* pParent, int seqNo, const String& name); 

	// creates a non-terminal
	ElementContentSpec(ElementContentSpec* pParent, int seqNo);

	~ElementContentSpec();

	const String& getName() const;
	
	ElementContentSpec& addTerminal(const String& elementName);
	ElementContentSpec& addPCData();
	bool containsTerminal(const String& elementName) const;
	ElementContentSpec& addChild();

	Multiplicity getMultiplicity() const;
	ListType getListType() const;
	const String& getElementName() const;
	bool isTerminal() const;
	bool isEmpty() const;
	bool doesAllowMultiple() const;
	bool doesAllowNone() const;
	bool isRequired() const;

	void setMultiplicity(Multiplicity eMultiplicity);
	void setListType(ListType eListType);

	void validate(ParserImpl& parser) const;
	bool validated() const;
	
	const ElementContentSpec* validateNextElement(const String& name) const;
	bool isEndElementPermitted() const;
	void generateNextSet(ParserImpl& parser);

	String getDisplayableNextList(const String& currentElementName) const;
	String getDisplayableRequiredList() const;
	String asString(bool bMixedElement) const;

	const ElementContentSpec* getTopParent() const;

protected:
	
	static void AddElementToSet(const ElementContentSpec* pSpec, Map& theMap, ParserImpl& parser);
	size_t getFirstElements(Map& theMap, ParserImpl& parser, size_t startChild) const;
	void getNextElementsFrom(int seqNo, Map& theMap, bool& bEndElementOK, ParserImpl& parser) const;

private:
	bool m_bEndElementOK;
	bool m_bNextSetComplete;
	Children m_children;
	String m_elementName;
	ListType m_eListType;
	Multiplicity m_eMultiplicity;
	Map m_nextSet;
	ElementContentSpec* m_pParent;
	int m_seqNo;
	bool m_bValidated;
};

OT_XML_NAMESPACE_END

#endif //OT_XML_ElementContentSpec_h
