//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:55 $
//
//==============================================================================

#ifndef OT_XML_ElementType_h
#define OT_XML_ElementType_h

#ifndef OT_XML_defs_h
#include "defs.h"
#endif //OT_XML_defs_h

#include "AttributeType.h"

#include "DTDObject.h"
#include "Attribute.h"
#include <map>

OT_XML_NAMESPACE_BEGIN

class Parser;
class ElementContentSpec;
class AttributeSet;

class OT_XML_PKG ElementType : public DTDObject
{
public:
	typedef RefPtr<AttributeType> RPAttrType;
	typedef std::map<String, RPAttrType, std::less<String> > AttributeTypeMap;
	
	enum ContentType {ANY, EMPTY, MIXED, SPECIFIED};

	ElementType(const QName& name);
	virtual ~ElementType();

	RefPtr<AttributeType> getAttributeType(const QName& name) const;
	RefPtr<AttributeType> addAttributeType(const QName& name, bool bExternallyDeclared);

	const QName& getName() const;
	bool isDefined() const;
	void setDefined(bool bDefined, bool bExternallyDeclared);

	const AttributeTypeMap& getAttributeTypeMap() const;

	bool hasIdAttribute() const;
	const String& getIdAttributeName() const;
	void setIdAttributeName(const String& rawname);

	bool hasNotationAttribute() const;
	const String& getNotationAttributeName() const;
	void setNotationAttributeName(const String& rawname);

	ElementContentSpec* getContentSpec() const;
	ContentType getContentType() const;
	String getContentTypeAsString() const;
	void setContentType(ContentType eContentType);

	virtual void validate(ParserImpl& parser) const;
	virtual void validateMissingAttributes(AttributeSet& attrSet, bool bValidate, ParserImpl& parser) const;

	bool containsEnum(const String& value) const;
	bool allowsCharData() const;
	bool allowsWhitespace() const;

private: // not implemented
	ElementType(const ElementType& rhs);            // cannot be copied
	ElementType& operator=(const ElementType& rhs); // nor assigned

private:
	AttributeTypeMap m_attributeTypeMap;
	QName m_name;
	bool m_bDefined;
	ContentType m_eContentType;
	ElementContentSpec* m_pContentSpec;
	String m_idAttributeName;
	String m_notationAttributeName;
};

OT_XML_NAMESPACE_END

#endif //OT_XML_ElementType_h
