//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:55 $
//
//==============================================================================

#ifndef OT_XML_Entity_h
#define OT_XML_Entity_h

#ifndef OT_XML_defs_h
#include "defs.h"
#endif //OT_XML_defs_h

#include "EntityType.h"
#include "ScannerPosition.h"
#include "DTDObject.h"

#include "ot/net/URL.h"

OT_XML_NAMESPACE_BEGIN

using net::URL;

class ParserImpl;

class OT_XML_PKG Entity : public DTDObject
{
public:

	Entity(EntityType type, const Entity* pParent, bool bExternallyDeclared);
	Entity(EntityType type, const Entity* pParent, bool bExternallyDeclared, const String& name);
	virtual ~Entity();

	virtual void validate(ParserImpl& parser) const;
	bool operator==(const Entity& rhs) const;
	bool operator!=(const Entity& rhs) const;
	EntityType getType() const;
	const String& getName() const;

	virtual bool isExternalEntity() const = 0;
	virtual bool isInternalEntity() const = 0;
	virtual bool isParsed() const = 0;
	virtual void load() = 0;
	virtual ScannerPosition getStartPosition() = 0;
	virtual RefPtr<Reader> getReader() const = 0;
	virtual String getResolvedSystemId() const;
	virtual String getBaseURI() const;
	virtual String getPublicId() const;
	virtual String getSystemId() const;

	const Entity* getParent() const;
	const Entity* getTopParent() const;

private: // not implemented
	Entity(const Entity& rhs);                  // entities cannot be copied
	const Entity& operator=(const Entity& rhs); // nor assigned

private:
	EntityType m_type;
	String m_name;
	const Entity* m_pParent;
};

OT_XML_NAMESPACE_END

#endif //OT_XML_Entity_h
