//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:57 $
//
//==============================================================================

#ifndef OT_XML_ExternalEntity_h
#define OT_XML_ExternalEntity_h

#ifndef OT_XML_defs_h
#include "defs.h"
#endif //OT_XML_defs_h

#include "Entity.h"
#include "XMLInputSource.h"
#include "ot/net/URL.h"

OT_XML_NAMESPACE_BEGIN

using net::URL;

class ParserImpl;

class OT_XML_PKG ExternalEntity : public Entity
{
public:

	ExternalEntity(ParserImpl& parser, EntityType type, XMLInputSource* pInputSource);
	
	ExternalEntity(ParserImpl& parser, EntityType type, const Entity* pParent,
	               bool bExternallyDeclared, const String& name,
	               const String& publicId, const String& systemId,
	               const String& notation);

	virtual ScannerPosition getStartPosition();
	virtual bool isParsed() const;
	virtual bool isExternalEntity() const;
	virtual bool isInternalEntity() const;
	virtual void load();
	bool isLoaded() const;
	
	virtual RefPtr<Reader> getReader() const;
	virtual String getResolvedSystemId() const;
	virtual String getBaseURI() const;
	virtual String getSystemId() const;
	virtual String getPublicId() const;
	const String& getNotation() const;

	virtual void validate(ParserImpl& parser) const;

protected:
	void createReader(ParserImpl& parser, const String& extEncoding, InputStream* pInputStream); 
	void init(XMLInputSource* pInputSource);
	void resolveEntity();

private:
	ParserImpl& m_parser;
	bool m_bLoaded;
	String m_notation;
	RefPtr<XMLInputSource> m_rpInputSource;
	RefPtr<Reader> m_rpReader;
	ScannerPosition m_startPosition;
	String m_resolvedSystemId;
	String m_systemId;
	String m_publicId;
};

OT_XML_NAMESPACE_END

#endif //OT_XML_ExternalEntity_h
