//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:25:57 $
//
//==============================================================================
//
// Class: Parser
// 
// Overview
// --------
// Abstract interface class.  The Parser interface represents the public
// interface exposed by the ElCel Technology XML Toolkit for parsing
// XML documents.
//
//==============================================================================

#ifndef OT_XML_Parser_h
#define OT_XML_Parser_h

#ifndef OT_XML_defs_h
#include "defs.h"
#endif //OT_XML_defs_h

OT_XML_NAMESPACE_BEGIN

class ContentEventHandler;
class DTDEventHandler;
class EntityResolutionHandler;
class EntityEventHandler;
class ErrorEventHandler;
class XMLInputSource;
class Position;
class ContextString;

class OT_XML_PKG Parser : public virtual ManagedObject
{

public:

	enum ErrorLevel {NoError=0, Warning, Error, Fatal};

	virtual void parseURL(const String& systemId) = 0;
	virtual void parseInputSource(XMLInputSource* pInputSource) = 0;
	
	virtual void parseDTD(const String& systemId) = 0;

	virtual bool isStandaloneDocument() const = 0;
	virtual ErrorLevel getDocumentError() const = 0;

	virtual const Position& getCurrentPosition() const = 0;
	virtual String getCurrentBaseURI() const = 0;

	virtual bool isFeatureEnabled(int featureID) const = 0; 
	virtual bool isFeatureSupported(int featureID) const = 0; 
	virtual void enableFeature(int featureID, bool bEnable) = 0;
	virtual bool isParseInProgress() const = 0;
	
	virtual void setDTDOverride(XMLInputSource* pDTDInputSource) = 0;
	virtual RefPtr<XMLInputSource> getDTDOverride() const = 0;
	
	//
	// EventHandler setting/getting methods.
	//
	// Note: ownership of the pointer remains with the caller,
	//       the EventHandler class is not reference-counted
	//
	virtual void setContentEventHandler(ContentEventHandler* npHandler) = 0;
	virtual void setDTDEventHandler(DTDEventHandler* npHandler) = 0;
	virtual void setEntityEventHandler(EntityEventHandler* npHandler) = 0;
	virtual void setErrorEventHandler(ErrorEventHandler* npHandler) = 0;
	virtual void setEntityResolutionHandler(EntityResolutionHandler* npHandler) = 0;

	virtual ContentEventHandler* getContentEventHandler() const = 0;
	virtual DTDEventHandler* getDTDEventHandler() const = 0;
	virtual EntityEventHandler* getEntityEventHandler() const = 0;
	virtual EntityResolutionHandler* getEntityResolutionHandler() const = 0;
	virtual ErrorEventHandler* getErrorEventHandler() const = 0;
};

OT_XML_NAMESPACE_END

#endif //OT_XML_Parser_h
