//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:26:06 $
//
//==============================================================================
//
// Class: QName
// 
// Overview
// --------
// A class to encapsulate a qualified XML name.
// 
// Qualified names are not part of the XML 1.0 standard - they were introduced
// as part of the XML Namespaces recommendation.
//
// Namespace processing is optional within the XML parser.  However, the QName
// class can still be used to represent raw XML 1.0 names.  In the case where
// namespace processing is switched off, the rawName element can be used.
// 
//==============================================================================

#ifndef OT_XML_QName_h
#define OT_XML_QName_h

#ifndef OT_XML_defs_h
#include "defs.h"
#endif //OT_XML_defs_h

OT_XML_NAMESPACE_BEGIN

class OT_XML_PKG QName
{
public:
	
	QName(const String& rawName,
	      const String& namespaceURI);

	QName(const String& rawName);
	
	QName(const QName& rhs);

	QName();

	bool operator==(const QName& rhs) const;
	bool operator!=(const QName& rhs) const;
	bool operator<(const QName& rhs) const; // used for sorting lexicographically

	const String& getRawName() const;
	String getPrefix() const;
	String getLocalName() const;
	const String& getNamespaceURI() const;
	size_t getDelimPosition() const;

	String getUniversalName() const;

	void setRawName(const String& rawName);
	void setNamespaceURI(const String& namespaceURI);

protected:
	void setDelimPosition();

private:
	String m_rawName;
	String m_namespaceURI;
	size_t m_delimPosition;
};

inline QName::QName() : m_delimPosition(String::npos)
{
}

inline QName::QName(const String& rawName, const String& namespaceURI) :
	m_rawName(rawName),
	m_namespaceURI(namespaceURI)
{
	setDelimPosition();
}

inline QName::QName(const String& rawName) :
	m_rawName(rawName)
{
	setDelimPosition();
}

inline QName::QName(const QName& rhs) :
	m_rawName(rhs.m_rawName),
	m_namespaceURI(rhs.m_namespaceURI),
	m_delimPosition(rhs.m_delimPosition)
{
}

inline void QName::setDelimPosition()
{
	m_delimPosition = m_rawName.find(':');
}

OT_XML_NAMESPACE_END

#endif //OT_XML_QName_h

