//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:26:07 $
//
//==============================================================================
//
// StreamPosition
//
// Used to record the relative human-understandable position within an input
// stream.  i.e. We record the position in terms of line and column number
// starting at position (1,1)
//
// This class also takes some of the workload from the scanner by incrementing
// position given a [sequence of] characters.
// 
//==============================================================================

#ifndef OT_XML_StreamPosition_h
#define OT_XML_StreamPosition_h

#ifndef OT_XML_defs_h
#include "defs.h"
#endif //OT_XML_defs_h 

OT_XML_NAMESPACE_BEGIN

class OT_XML_PKG StreamPosition
{
public:
	StreamPosition();

	void incrementByChar(const Character& ch); 
	void incrementByString(const String& str); 
	void decrementColumns(size_t colCount); 

	bool operator==(const StreamPosition& rhs) const;
	bool operator!=(const StreamPosition& rhs) const;

	size_t getLineNo() const;
	size_t getColNo() const;
	size_t getOffset() const;

private:
	size_t m_lineNo;
	size_t m_colNo;
	size_t m_offset;
};

OT_XML_NAMESPACE_END

#if OT_XML_INCLUDE_INLINES
	#include "StreamPosition.inl"
#endif

#endif //OT_XML_StreamPosition_h

