//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:26:07 $
//
//==============================================================================

#include "defs.h"

#include "ot/base/debug.h"

OT_XML_NAMESPACE_BEGIN

inline StreamPosition::StreamPosition() :
	m_lineNo(1),
	m_colNo(1),
	m_offset(0)
{
}

inline size_t StreamPosition::getLineNo() const
{
	return m_lineNo;
}

inline size_t StreamPosition::getColNo() const
{
	return m_colNo;
}

inline size_t StreamPosition::getOffset() const
{
	return m_offset;
}

inline void StreamPosition::incrementByChar(const Character& ch)
{
	m_offset++;
	if(ch == '\n')
	{
		m_lineNo++;
		m_colNo=1;
	}
	else
	{
		m_colNo++;
	}
}

inline void StreamPosition::incrementByString(const String& str)
{
	for(String::const_iterator it=str.begin(); it!=str.end(); ++it)
	{
		// replicated StreamPosition::incrementByChar(CharType ch)
		// to avoid function call overhead!
		m_offset++;
		if(*it == '\n')
		{
			m_lineNo++;
			m_colNo=1;
		}
		else
		{
			m_colNo++;
		}
	}
}

inline bool StreamPosition::operator==(const StreamPosition& rhs) const
{
	return (m_offset == rhs.m_offset);
}

inline bool StreamPosition::operator!=(const StreamPosition& rhs) const
{
	return !(*this==rhs);
}

inline void StreamPosition::decrementColumns(size_t colCount)
{
	OT_DBG_ASSERT(colCount < m_colNo);
	OT_DBG_ASSERT(colCount <= m_offset);
	m_colNo -= colCount;
	m_offset -= colCount;
}

OT_XML_NAMESPACE_END
