//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/01/22 21:07:55 $
//
//==============================================================================
/**
	@namespace ot::xml

	Contains classes representing the native interface to
	the @OpenTop XML parser.  

	<p>Applications that do not require the additional
	features provided by the native interface are encouraged to use the
	standard interface provided by the ot::sax namespace.</p>
*/
//==============================================================================

#ifndef OT_XML_defs_h
#define OT_XML_defs_h

#include "ot/base/gendefs.h"
#include "ot/base/Character.h"
#include "ot/base/ManagedObject.h"
#include "ot/base/RefPtr.h"
#include "ot/base/String.h"
#include "ot/io/InputStream.h"
#include "ot/io/Reader.h"

//
// Include XML Toolkit version macros
//
#include "version.h"

//
// Win32 DLL Versions of the library
//
#if defined(WIN32) && defined(OT_DLL)
	#if defined OT_XML_EXPORT
		#define OT_OTXML_PKG __declspec(dllexport)
		#define OT_OTXML_INCLUDE_INLINES 1
	#else
		#define OT_OTXML_PKG __declspec(dllimport)
		#if defined(_MSC_VER) && 1300 <= _MSC_VER
			#define OT_OTXML_INCLUDE_INLINES 0
		#else
			#define OT_OTXML_INCLUDE_INLINES 1
		#endif
	#endif
#else
	#define OT_OTXML_PKG
	#define OT_OTXML_INCLUDE_INLINES 1
#endif


#define OT_XML_PKG OT_OTXML_PKG
#define OT_XML_INCLUDE_INLINES OT_OTXML_INCLUDE_INLINES
#define OT_XML_NAMESPACE_BEGIN OT_SUB_NAMESPACE_BEGIN(xml)
#define OT_XML_NAMESPACE_END   OT_SUB_NAMESPACE_END(xml)

//
// Under MSVC, automatically link to requirted library
//
#if defined(_MSC_VER) && !defined(OT_XML_EXPORT)
#include "ot/base/libname.h"
#pragma comment(lib, OT_LIBNAME(otxml))
#endif

//
// import types into the xml namespace:
//
OT_XML_NAMESPACE_BEGIN

using io::InputStream;
using io::Reader;

OT_XML_NAMESPACE_END

#endif //OT_XML_defs_h



