//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:27:05 $
//
//==============================================================================
//
// Class: CatalogEntry
// 
// Overview
// --------
// A CatalogEntry derivative for leaf nodes.
//
//==============================================================================

#ifndef OT_XMLCAT_CatalogEntry_h
#define OT_XMLCAT_CatalogEntry_h

#include "defs.h"
#include "CatalogResolver.h"
#include "CatalogFile.h"

OT_XMLCAT_NAMESPACE_BEGIN

class OT_XMLCAT_PKG CatalogEntry
{
public:
	enum EntryType {PUBLIC, SYSTEM, REWRITE_SYSTEM, URI, REWRITE_URI};

	CatalogEntry(const String& identifier,
	             EntryType eEntryType,
				 CatalogResolver::Preference ePreference);

	virtual ~CatalogEntry();

	const String& getIdentifier() const;

	EntryType getEntryType() const;

	CatalogResolver::Preference getPreference() const;

	// Resolver functions
	virtual bool resolveEntity(const String& publicId, const String& systemId,
	                           const CatalogFile::List& catList,
	                           String& returnUri, bool& bDelegated) const =0;

	virtual bool resolveURI(const String& uri, const CatalogFile::List& catList,
	                        String& returnUri, bool& bDelegated) const =0;

protected:
	String m_identifier;
	EntryType m_eEntryType;
	CatalogResolver::Preference m_ePreference;
};

OT_XMLCAT_NAMESPACE_END

#endif //OT_XMLCAT_CatalogEntry_h
