//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:27:06 $
//
//==============================================================================
//
// Class: CatalogFile
// 
// Overview
// --------
// A class to encapsulate an XML Entity Resolution Catalog document.
// 
// This is an implementation of the (draft) specification from
// the Oasis Entity Resolution Technical Committee
// http://www.oasis-open.org/committees/entityspec-2001-05-07.html
//
//==============================================================================

#ifndef OT_XMLCAT_CatalogFile_h
#define OT_XMLCAT_CatalogFile_h

#include "defs.h"
#include <deque>
#include <list>

OT_XMLCAT_NAMESPACE_BEGIN

class CatalogSet;
class CatalogEntry;
class CatalogDelegatorEntry;

class OT_XMLCAT_PKG CatalogFile : public virtual ManagedObject
{
	friend class CatalogParserHandler;

public:

	CatalogFile(const URL& url, CatalogSet& catalogSet);
	~CatalogFile();

	typedef std::list<String> List;

	bool resolveEntity(const String& publicId, const String& systemId,
	                   const List& catList, 
	                   String& returnUri, bool& bDelegated) const;

	bool resolveURI(const String& uri, const List& catList, 
	                String& returnUri, bool& bDelegated) const;

	CatalogSet& getEnclosingSet() const;

	const URL& getURL() const;

protected:

	void open();
	void addLeafEntry(CatalogEntry* pCatalogEntry);
	void addDelegatorEntry(CatalogDelegatorEntry* pCatalogEntry);
	bool testCircularReference(const List& catList) const;

private:

	typedef std::deque<CatalogEntry*> CatalogEntryList;
	typedef std::deque<CatalogDelegatorEntry*> CatalogDelegatorEntryList;
	CatalogEntryList m_uriEntryList;
	CatalogEntryList m_rewriteUriEntryList;
	CatalogEntryList m_publicEntryList;
	CatalogEntryList m_systemEntryList;
	CatalogEntryList m_rewriteSystemEntryList;
	CatalogDelegatorEntryList m_uriDelegatorList;
	CatalogDelegatorEntryList m_publicDelegatorList;
	CatalogDelegatorEntryList m_systemDelegatorList;

	URL m_url;
	CatalogSet& m_enclosingSet;
	bool m_bOpen;
};

OT_XMLCAT_NAMESPACE_END

#endif //OT_XMLCAT_CatalogFile_h

