//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.2 $
// $Date: 2003/04/09 21:47:44 $
//
//==============================================================================

#ifndef CatalogParserHandler_h
#define CatalogParserHandler_h

#include "defs.h"
#include "CatalogSerialisationContext.h"

#include "ot/xml/ContentEventHandler.h"
#include "ot/xml/ErrorEventHandler.h"
#include "ot/xml/Parser.h"

#include <stack>
#include <deque>

OT_XMLCAT_NAMESPACE_BEGIN

using namespace xml;

class CatalogFile;

class OT_XMLCAT_PKG CatalogParserHandler : public ContentEventHandler,
                                           public ErrorEventHandler
{
public:

	CatalogParserHandler(CatalogFile& catalogFile, const Parser& parser);
	virtual ~CatalogParserHandler();
	
protected:

	// ContentEventHandler methods...
	virtual void onComment(const CharType* pComment, size_t length);
	virtual void onCommentStart(bool bInsideDTD);
	virtual void onCommentEnd(bool bInsideDTD);
	virtual void onPI(const String& PITarget, const String& PIValue);
	virtual void onStartElement(const QName& elementName, bool bEmptyElement, const AttributeSet& attributes);
	virtual void onEndElement(const QName& elementName);
	virtual void onWhitespace(const CharType* pStr, size_t len);
	virtual void onIgnorableWhitespace(const CharType* pStr, size_t len);
	virtual void onCharData(const CharType* pStr, size_t len);
	virtual void onStartCData();
	virtual void onEndCData();
	virtual void onNamespaceBegin(const String& prefix, const String& uri);
	virtual void onNamespaceChange(const String& prefix, const String& uriFrom, const String& uriTo, bool bRestoring);
	virtual void onNamespaceEnd(const String& prefix, const String& uri);
	virtual void onStartDocument(const String& systemId);
	virtual void onEndDocument();
	virtual void onXMLDeclaration(const String& version, const String& encoding, bool bStandalone);

	// ErrorEventHandler methods...
	virtual void onError(int level,
	                     long /*reserved*/,
	                     const String& message,
	                     const Position& position,
	                     const ContextString* pContextString);


protected:
	void createCatalogEntry(const String& elementName,
	                        const AttributeSet& attributes,
	                        CatalogSerialisationContext& context);

	String getRequiredAttribute(const String& elementName,
	                            const String& attrName,
	                            const AttributeSet& attributes);

	void reportError(int level, const String& message, const Position& position);

private:
	CatalogFile& m_catalogFile;
	typedef std::stack<CatalogSerialisationContext, std::deque<CatalogSerialisationContext> > ContextStack;
	ContextStack m_contextStack;
	const Parser& m_parser;
};

OT_XMLCAT_NAMESPACE_END

#endif // CatalogParserHandler_h
