//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:27:07 $
//
//==============================================================================
//
// Class: CatalogResolver
// 
// Overview
// --------
// A class to act as the ublic interface to XML Entity Resolution using
// Oasis XML Catalogs.
//
// The CatalogResolver holds a CatalogSet which contains a number of
// CatalogFiles, each CatalogFile representing the catalog entries from a 
// particular catalog file.
// 
// This is an implementation of the (draft) specification from
// the Oasis Entity Resolution Technical Committee
// http://www.oasis-open.org/committees/entityspec-2001-05-25.html
//
//==============================================================================

#ifndef OT_XMLCAT_CatalogResolver_h
#define OT_XMLCAT_CatalogResolver_h

#include "defs.h"

OT_XMLCAT_NAMESPACE_BEGIN

class CatalogEventHandler;
class CatalogSet;

class OT_XMLCAT_PKG CatalogResolver : public virtual ManagedObject
{

public:

	enum Preference {PUBLIC, SYSTEM};

	CatalogResolver();
	~CatalogResolver();

	void addPrimaryCatalog(const URL& url);
	void addSecondaryCatalog(const URL& url);
	void resetSecondaryCatalog();

	bool resolveEntity(const String& publicId, const String& systemId,
                       String& returnUri) const;

	bool resolveURI(const String& uri, String& returnUri) const;

	CatalogEventHandler* getEventHandler() const;
	void setEventHandler(CatalogEventHandler* pHandler);

	static void SetGlobalPreference(Preference ePreference);
	static Preference GetGlobalPreference();
	static bool IsPublicidURN(const String& urn);
	static String UnwrapPublicidURN(const String& urn);
	static String GetCatalogPITarget();

private:
	CatalogSet* m_pPrimaryCatalogSet;
	CatalogSet* m_pSecondaryCatalogSet;
	CatalogEventHandler* m_pEventHandler;
	
	static Preference s_eGlobalPreference;
};

OT_XMLCAT_NAMESPACE_END

#endif //OT_XMLCAT_CatalogResolver_h
