//==============================================================================
// This file is part of the OpenTop C++ Library.
// (c) Copyright 2000-2002 ElCel Technology Limited
//
// This file may be distributed and/or modified under the terms of the
// GNU General Public License version 2 as published by the Free Software
// Foundation and appearing in the file LICENSE.GPL included in the
// packaging of this file.
//
// Licensees holding valid OpenTop Commercial licences may use this file
// in accordance with the OpenTop Commercial License Agreement included
// with the software.
//
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// See http://www.elcel.com/products/opentop/pricing.html or email
// sales@elcel.com for information about OpenTop Commercial License Agreements.
//
//==============================================================================
//
// $Revision: 1.1.1.1 $
// $Date: 2002/12/14 00:27:07 $
//
//==============================================================================
//
// Class: CatalogSet
// 
// Overview
// --------
// A container class for a set of CatalogFiles.
//
//==============================================================================

#ifndef OT_XMLCAT_CatalogSet_h
#define OT_XMLCAT_CatalogSet_h

#include "defs.h"
#include "CatalogFile.h"
#include <list>

OT_XMLCAT_NAMESPACE_BEGIN

class CatalogResolver;

class OT_XMLCAT_PKG CatalogSet
{
	friend class CatalogParserHandler;
	friend class CatalogSetDelegatorEntry;

public:
	
	CatalogSet(const CatalogResolver& resolver);

	bool resolveEntity(const String& publicId, const String& systemId,
	                   const CatalogFile::List& catList, String& returnUri,
					   bool& bReturnDelegated) const;

	bool resolveURI(const String& uri, const CatalogFile::List& catList,
	                String& returnUri, bool& bReturnDelegated) const;

	void addFile(const URL& catalogFile, const CatalogFile* pFrom=0);

	const CatalogResolver& getResolver() const;

private:
	typedef std::list< RefPtr<CatalogFile> > CatalogFiles;
	CatalogFiles m_catalogFiles;
	const CatalogResolver& m_resolver;
};

OT_XMLCAT_NAMESPACE_END

#endif //OT_XMLCAT_CatalogSet_h

